/****************************************************************************
** Meta object code from reading C++ file 'bluetoothadapteritem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plugins/dde-dock/bluetooth/componments/bluetoothadapteritem.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothadapteritem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19BluetoothDeviceItemE_t {};
} // unnamed namespace

template <> constexpr inline auto BluetoothDeviceItem::qt_create_metaobjectdata<qt_meta_tag_ZN19BluetoothDeviceItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluetoothDeviceItem",
        "requestTopDeviceItem",
        "",
        "PluginStandardItem*",
        "item",
        "deviceStateChanged",
        "const Device*",
        "device",
        "disconnectDevice",
        "updateDeviceState",
        "Device::State",
        "state"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestTopDeviceItem'
        QtMocHelpers::SignalData<void(PluginStandardItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceStateChanged'
        QtMocHelpers::SignalData<void(const Device *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'disconnectDevice'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateDeviceState'
        QtMocHelpers::SlotData<void(Device::State)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BluetoothDeviceItem, qt_meta_tag_ZN19BluetoothDeviceItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluetoothDeviceItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BluetoothDeviceItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BluetoothDeviceItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19BluetoothDeviceItemE_t>.metaTypes,
    nullptr
} };

void BluetoothDeviceItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothDeviceItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestTopDeviceItem((*reinterpret_cast<std::add_pointer_t<PluginStandardItem*>>(_a[1]))); break;
        case 1: _t->deviceStateChanged((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 2: _t->disconnectDevice(); break;
        case 3: _t->updateDeviceState((*reinterpret_cast<std::add_pointer_t<Device::State>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginStandardItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothDeviceItem::*)(PluginStandardItem * )>(_a, &BluetoothDeviceItem::requestTopDeviceItem, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDeviceItem::*)(const Device * )>(_a, &BluetoothDeviceItem::deviceStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDeviceItem::*)()>(_a, &BluetoothDeviceItem::disconnectDevice, 2))
            return;
    }
}

const QMetaObject *BluetoothDeviceItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluetoothDeviceItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BluetoothDeviceItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluetoothDeviceItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void BluetoothDeviceItem::requestTopDeviceItem(PluginStandardItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluetoothDeviceItem::deviceStateChanged(const Device * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluetoothDeviceItem::disconnectDevice()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN19DeviceControlWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto DeviceControlWidget::qt_create_metaobjectdata<qt_meta_tag_ZN19DeviceControlWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeviceControlWidget",
        "expandStateChanged",
        "",
        "state"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'expandStateChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeviceControlWidget, qt_meta_tag_ZN19DeviceControlWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DeviceControlWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QPushButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeviceControlWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeviceControlWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DeviceControlWidgetE_t>.metaTypes,
    nullptr
} };

void DeviceControlWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceControlWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->expandStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceControlWidget::*)(bool )>(_a, &DeviceControlWidget::expandStateChanged, 0))
            return;
    }
}

const QMetaObject *DeviceControlWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeviceControlWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeviceControlWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QPushButton::qt_metacast(_clname);
}

int DeviceControlWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPushButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DeviceControlWidget::expandStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN20BluetoothAdapterItemE_t {};
} // unnamed namespace

template <> constexpr inline auto BluetoothAdapterItem::qt_create_metaobjectdata<qt_meta_tag_ZN20BluetoothAdapterItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluetoothAdapterItem",
        "adapterPowerChanged",
        "",
        "requestSetAdapterPower",
        "Adapter*",
        "adapter",
        "state",
        "requestRefreshAdapter",
        "connectDevice",
        "const Device*",
        "device",
        "deviceCountChanged",
        "deviceStateChanged",
        "onDeviceAdded",
        "onDeviceRemoved",
        "onDeviceNameUpdated",
        "onConnectDevice",
        "QModelIndex",
        "index",
        "onTopDeviceItem",
        "PluginStandardItem*",
        "item",
        "onAdapterNameChanged",
        "name",
        "sizeHint",
        "QSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'adapterPowerChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSetAdapterPower'
        QtMocHelpers::SignalData<void(Adapter *, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'requestRefreshAdapter'
        QtMocHelpers::SignalData<void(Adapter *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'connectDevice'
        QtMocHelpers::SignalData<void(const Device *, Adapter *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'deviceCountChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceStateChanged'
        QtMocHelpers::SignalData<void(const Device *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const Device *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onDeviceRemoved'
        QtMocHelpers::SlotData<void(const Device *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onDeviceNameUpdated'
        QtMocHelpers::SlotData<void(const Device *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onConnectDevice'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'onTopDeviceItem'
        QtMocHelpers::SlotData<void(PluginStandardItem *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'onAdapterNameChanged'
        QtMocHelpers::SlotData<void(const QString)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'sizeHint'
        QtMocHelpers::SlotData<QSize() const>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BluetoothAdapterItem, qt_meta_tag_ZN20BluetoothAdapterItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluetoothAdapterItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20BluetoothAdapterItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20BluetoothAdapterItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20BluetoothAdapterItemE_t>.metaTypes,
    nullptr
} };

void BluetoothAdapterItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothAdapterItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->adapterPowerChanged(); break;
        case 1: _t->requestSetAdapterPower((*reinterpret_cast<std::add_pointer_t<Adapter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->requestRefreshAdapter((*reinterpret_cast<std::add_pointer_t<Adapter*>>(_a[1]))); break;
        case 3: _t->connectDevice((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Adapter*>>(_a[2]))); break;
        case 4: _t->deviceCountChanged(); break;
        case 5: _t->deviceStateChanged((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 6: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 7: _t->onDeviceRemoved((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 8: _t->onDeviceNameUpdated((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 9: _t->onConnectDevice((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->onTopDeviceItem((*reinterpret_cast<std::add_pointer_t<PluginStandardItem*>>(_a[1]))); break;
        case 11: _t->onAdapterNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { QSize _r = _t->sizeHint();
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginStandardItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapterItem::*)()>(_a, &BluetoothAdapterItem::adapterPowerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapterItem::*)(Adapter * , bool )>(_a, &BluetoothAdapterItem::requestSetAdapterPower, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapterItem::*)(Adapter * )>(_a, &BluetoothAdapterItem::requestRefreshAdapter, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapterItem::*)(const Device * , Adapter * )>(_a, &BluetoothAdapterItem::connectDevice, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapterItem::*)()>(_a, &BluetoothAdapterItem::deviceCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapterItem::*)(const Device * )>(_a, &BluetoothAdapterItem::deviceStateChanged, 5))
            return;
    }
}

const QMetaObject *BluetoothAdapterItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluetoothAdapterItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20BluetoothAdapterItemE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int BluetoothAdapterItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void BluetoothAdapterItem::adapterPowerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BluetoothAdapterItem::requestSetAdapterPower(Adapter * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void BluetoothAdapterItem::requestRefreshAdapter(Adapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluetoothAdapterItem::connectDevice(const Device * _t1, Adapter * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void BluetoothAdapterItem::deviceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BluetoothAdapterItem::deviceStateChanged(const Device * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
