/****************************************************************************
** Meta object code from reading C++ file 'inputdevice1keyboardinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "inputdevice1keyboardinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputdevice1keyboardinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeInputDevice1KeyboardInterface::qt_create_metaobjectdata<qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeInputDevice1KeyboardInterface",
        "CapslockToggleChanged",
        "",
        "value",
        "CurrentLayoutChanged",
        "CursorBlinkChanged",
        "LayoutScopeChanged",
        "RepeatDelayChanged",
        "RepeatEnabledChanged",
        "RepeatIntervalChanged",
        "UserLayoutListChanged",
        "UserOptionListChanged",
        "AddLayoutOption",
        "QDBusPendingReply<>",
        "in0",
        "AddLayoutOptionQueued",
        "AddUserLayout",
        "AddUserLayoutQueued",
        "ClearLayoutOption",
        "ClearLayoutOptionQueued",
        "DeleteLayoutOption",
        "DeleteLayoutOptionQueued",
        "DeleteUserLayout",
        "DeleteUserLayoutQueued",
        "GetLayoutDesc",
        "QDBusPendingReply<QString>",
        "LayoutList",
        "QDBusPendingReply<KeyboardLayoutList>",
        "Reset",
        "ResetQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "CapslockToggle",
        "CurrentLayout",
        "CursorBlink",
        "LayoutScope",
        "RepeatDelay",
        "RepeatEnabled",
        "RepeatInterval",
        "UserLayoutList",
        "UserOptionList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CapslockToggleChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'CurrentLayoutChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'CursorBlinkChanged'
        QtMocHelpers::SignalData<void(int) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LayoutScopeChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'RepeatDelayChanged'
        QtMocHelpers::SignalData<void(uint) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'RepeatEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'RepeatIntervalChanged'
        QtMocHelpers::SignalData<void(uint) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'UserLayoutListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'UserOptionListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'AddLayoutOption'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'AddLayoutOptionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'AddUserLayout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'AddUserLayoutQueued'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'ClearLayoutOption'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(18, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'ClearLayoutOptionQueued'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DeleteLayoutOption'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'DeleteLayoutOptionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'DeleteUserLayout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'DeleteUserLayoutQueued'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'GetLayoutDesc'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'LayoutList'
        QtMocHelpers::SlotData<QDBusPendingReply<KeyboardLayoutList>()>(26, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(28, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'ResetQueued'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 39, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CapslockToggle'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'CurrentLayout'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'CursorBlink'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'LayoutScope'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'RepeatDelay'
        QtMocHelpers::PropertyData<uint>(44, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'RepeatEnabled'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'RepeatInterval'
        QtMocHelpers::PropertyData<uint>(46, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'UserLayoutList'
        QtMocHelpers::PropertyData<QStringList>(47, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'UserOptionList'
        QtMocHelpers::PropertyData<QStringList>(48, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeInputDevice1KeyboardInterface, qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeInputDevice1KeyboardInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeInputDevice1KeyboardInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeInputDevice1KeyboardInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CapslockToggleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->CurrentLayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->CursorBlinkChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->LayoutScopeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->RepeatDelayChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: _t->RepeatEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->RepeatIntervalChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->UserLayoutListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->UserOptionListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 9: { QDBusPendingReply<> _r = _t->AddLayoutOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->AddLayoutOptionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QDBusPendingReply<> _r = _t->AddUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->AddUserLayoutQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { QDBusPendingReply<> _r = _t->ClearLayoutOption();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->ClearLayoutOptionQueued(); break;
        case 15: { QDBusPendingReply<> _r = _t->DeleteLayoutOption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->DeleteLayoutOptionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: { QDBusPendingReply<> _r = _t->DeleteUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->DeleteUserLayoutQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: { QDBusPendingReply<QString> _r = _t->GetLayoutDesc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<KeyboardLayoutList> _r = _t->LayoutList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<KeyboardLayoutList>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->ResetQueued(); break;
        case 23: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 24: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 25: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(bool ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::CapslockToggleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(const QString & ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::CurrentLayoutChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(int ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::CursorBlinkChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(int ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::LayoutScopeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(uint ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::RepeatDelayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(bool ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::RepeatEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(uint ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::RepeatIntervalChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(const QStringList & ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::UserLayoutListChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeInputDevice1KeyboardInterface::*)(const QStringList & ) const>(_a, &__OrgDeepinDdeInputDevice1KeyboardInterface::UserOptionListChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->capslockToggle(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentLayout(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->cursorBlink(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->layoutScope(); break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->repeatDelay(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->repeatEnabled(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->repeatInterval(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->userLayoutList(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->userOptionList(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCapslockToggle(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setCurrentLayout(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setCursorBlink(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setLayoutScope(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setRepeatDelay(*reinterpret_cast<uint*>(_v)); break;
        case 5: _t->setRepeatEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setRepeatInterval(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeInputDevice1KeyboardInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeInputDevice1KeyboardInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN43__OrgDeepinDdeInputDevice1KeyboardInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeInputDevice1KeyboardInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeInputDevice1KeyboardInterface::CapslockToggleChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdeInputDevice1KeyboardInterface::CurrentLayoutChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeInputDevice1KeyboardInterface::CursorBlinkChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeInputDevice1KeyboardInterface::LayoutScopeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeInputDevice1KeyboardInterface::RepeatDelayChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeInputDevice1KeyboardInterface::RepeatEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeInputDevice1KeyboardInterface::RepeatIntervalChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdeInputDevice1KeyboardInterface::UserLayoutListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdeInputDevice1KeyboardInterface::UserOptionListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeInputDevice1KeyboardInterface *>(this), &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
