/****************************************************************************
** Meta object code from reading C++ file 'airplanemode1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "airplanemode1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'airplanemode1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeAirplaneMode1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeAirplaneMode1Interface",
        "BluetoothEnabledChanged",
        "",
        "value",
        "EnabledChanged",
        "WifiEnabledChanged",
        "DumpState",
        "QDBusPendingReply<>",
        "DumpStateQueued",
        "Enable",
        "enabled",
        "EnableQueued",
        "EnableBluetooth",
        "EnableBluetoothQueued",
        "EnableWifi",
        "EnableWifiQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "BluetoothEnabled",
        "Enabled",
        "WifiEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BluetoothEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'EnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'WifiEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'DumpState'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(6, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'DumpStateQueued'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Enable'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(9, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'EnableQueued'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'EnableBluetooth'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(12, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'EnableBluetoothQueued'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'EnableWifi'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(14, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'EnableWifiQueued'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'BluetoothEnabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'Enabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'WifiEnabled'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeAirplaneMode1Interface, qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeAirplaneMode1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeAirplaneMode1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeAirplaneMode1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BluetoothEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->EnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->WifiEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: { QDBusPendingReply<> _r = _t->DumpState();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->DumpStateQueued(); break;
        case 5: { QDBusPendingReply<> _r = _t->Enable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->EnableQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: { QDBusPendingReply<> _r = _t->EnableBluetooth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->EnableBluetoothQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: { QDBusPendingReply<> _r = _t->EnableWifi((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->EnableWifiQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 12: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 13: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAirplaneMode1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeAirplaneMode1Interface::BluetoothEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAirplaneMode1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeAirplaneMode1Interface::EnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAirplaneMode1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeAirplaneMode1Interface::WifiEnabledChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bluetoothEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->wifiEnabled(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeAirplaneMode1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeAirplaneMode1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36__OrgDeepinDdeAirplaneMode1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeAirplaneMode1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeAirplaneMode1Interface::BluetoothEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAirplaneMode1Interface *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdeAirplaneMode1Interface::EnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAirplaneMode1Interface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeAirplaneMode1Interface::WifiEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAirplaneMode1Interface *>(this), &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
