/****************************************************************************
** Meta object code from reading C++ file 'statusnotifieriteminterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "statusnotifieriteminterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusnotifieriteminterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20__StatusNotifierItemE_t {};
} // unnamed namespace

template <> constexpr inline auto __StatusNotifierItem::qt_create_metaobjectdata<qt_meta_tag_ZN20__StatusNotifierItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__StatusNotifierItem",
        "NewAttentionIcon",
        "",
        "NewIcon",
        "NewOverlayIcon",
        "NewStatus",
        "status",
        "NewTitle",
        "NewToolTip",
        "AttentionIconNameChanged",
        "value",
        "AttentionIconPixmapChanged",
        "DBusImageList",
        "AttentionMovieNameChanged",
        "CategoryChanged",
        "IconNameChanged",
        "IconPixmapChanged",
        "IconThemePathChanged",
        "IdChanged",
        "ItemIsMenuChanged",
        "MenuChanged",
        "QDBusObjectPath",
        "OverlayIconNameChanged",
        "OverlayIconPixmapChanged",
        "StatusChanged",
        "TitleChanged",
        "ToolTipChanged",
        "DBusToolTip",
        "WindowIdChanged",
        "Activate",
        "QDBusPendingReply<>",
        "x",
        "y",
        "ActivateQueued",
        "ContextMenu",
        "ContextMenuQueued",
        "ProvideXdgActivationToken",
        "token",
        "ProvideXdgActivationTokenQueued",
        "Scroll",
        "delta",
        "orientation",
        "ScrollQueued",
        "SecondaryActivate",
        "SecondaryActivateQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "AttentionIconName",
        "AttentionIconPixmap",
        "AttentionMovieName",
        "Category",
        "IconName",
        "IconPixmap",
        "IconThemePath",
        "Id",
        "ItemIsMenu",
        "Menu",
        "OverlayIconName",
        "OverlayIconPixmap",
        "Status",
        "Title",
        "ToolTip",
        "WindowId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'NewAttentionIcon'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewIcon'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewOverlayIcon'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewStatus'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'NewTitle'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewToolTip'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AttentionIconNameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'AttentionIconPixmapChanged'
        QtMocHelpers::SignalData<void(DBusImageList) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Signal 'AttentionMovieNameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'CategoryChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'IconNameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'IconPixmapChanged'
        QtMocHelpers::SignalData<void(DBusImageList) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Signal 'IconThemePathChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'IdChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'ItemIsMenuChanged'
        QtMocHelpers::SignalData<void(bool) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'MenuChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 10 },
        }}),
        // Signal 'OverlayIconNameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'OverlayIconPixmapChanged'
        QtMocHelpers::SignalData<void(DBusImageList) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Signal 'StatusChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'TitleChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'ToolTipChanged'
        QtMocHelpers::SignalData<void(DBusToolTip) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 10 },
        }}),
        // Signal 'WindowIdChanged'
        QtMocHelpers::SignalData<void(int) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'Activate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'ActivateQueued'
        QtMocHelpers::SlotData<void(int, int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'ContextMenu'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(34, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'ContextMenuQueued'
        QtMocHelpers::SlotData<void(int, int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'ProvideXdgActivationToken'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'ProvideXdgActivationTokenQueued'
        QtMocHelpers::SlotData<void(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'Scroll'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Int, 40 }, { QMetaType::QString, 41 },
        }}),
        // Slot 'ScrollQueued'
        QtMocHelpers::SlotData<void(int, const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 }, { QMetaType::QString, 41 },
        }}),
        // Slot 'SecondaryActivate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(43, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'SecondaryActivateQueued'
        QtMocHelpers::SlotData<void(int, int)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 53 }, { 0x80000000 | 54, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AttentionIconName'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'AttentionIconPixmap'
        QtMocHelpers::PropertyData<DBusImageList>(56, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'AttentionMovieName'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'Category'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'IconName'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'IconPixmap'
        QtMocHelpers::PropertyData<DBusImageList>(60, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'IconThemePath'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'Id'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'ItemIsMenu'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'Menu'
        QtMocHelpers::PropertyData<QDBusObjectPath>(64, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'OverlayIconName'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'OverlayIconPixmap'
        QtMocHelpers::PropertyData<DBusImageList>(66, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'Status'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'Title'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags, 19),
        // property 'ToolTip'
        QtMocHelpers::PropertyData<DBusToolTip>(69, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 20),
        // property 'WindowId'
        QtMocHelpers::PropertyData<int>(70, QMetaType::Int, QMC::DefaultPropertyFlags, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__StatusNotifierItem, qt_meta_tag_ZN20__StatusNotifierItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __StatusNotifierItem::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20__StatusNotifierItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20__StatusNotifierItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20__StatusNotifierItemE_t>.metaTypes,
    nullptr
} };

void __StatusNotifierItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__StatusNotifierItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->NewAttentionIcon(); break;
        case 1: _t->NewIcon(); break;
        case 2: _t->NewOverlayIcon(); break;
        case 3: _t->NewStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->NewTitle(); break;
        case 5: _t->NewToolTip(); break;
        case 6: _t->AttentionIconNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->AttentionIconPixmapChanged((*reinterpret_cast<std::add_pointer_t<DBusImageList>>(_a[1]))); break;
        case 8: _t->AttentionMovieNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->CategoryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->IconNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->IconPixmapChanged((*reinterpret_cast<std::add_pointer_t<DBusImageList>>(_a[1]))); break;
        case 12: _t->IconThemePathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->IdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->ItemIsMenuChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->MenuChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 16: _t->OverlayIconNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->OverlayIconPixmapChanged((*reinterpret_cast<std::add_pointer_t<DBusImageList>>(_a[1]))); break;
        case 18: _t->StatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->TitleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->ToolTipChanged((*reinterpret_cast<std::add_pointer_t<DBusToolTip>>(_a[1]))); break;
        case 21: _t->WindowIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: { QDBusPendingReply<> _r = _t->Activate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->ActivateQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: { QDBusPendingReply<> _r = _t->ContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->ContextMenuQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 26: { QDBusPendingReply<> _r = _t->ProvideXdgActivationToken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->ProvideXdgActivationTokenQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: { QDBusPendingReply<> _r = _t->Scroll((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->ScrollQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: { QDBusPendingReply<> _r = _t->SecondaryActivate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->SecondaryActivateQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 32: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 33: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 34: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusImageList >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusImageList >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusImageList >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusToolTip >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)()>(_a, &__StatusNotifierItem::NewAttentionIcon, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)()>(_a, &__StatusNotifierItem::NewIcon, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)()>(_a, &__StatusNotifierItem::NewOverlayIcon, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & )>(_a, &__StatusNotifierItem::NewStatus, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)()>(_a, &__StatusNotifierItem::NewTitle, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)()>(_a, &__StatusNotifierItem::NewToolTip, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::AttentionIconNameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(DBusImageList ) const>(_a, &__StatusNotifierItem::AttentionIconPixmapChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::AttentionMovieNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::CategoryChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::IconNameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(DBusImageList ) const>(_a, &__StatusNotifierItem::IconPixmapChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::IconThemePathChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::IdChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(bool ) const>(_a, &__StatusNotifierItem::ItemIsMenuChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QDBusObjectPath & ) const>(_a, &__StatusNotifierItem::MenuChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::OverlayIconNameChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(DBusImageList ) const>(_a, &__StatusNotifierItem::OverlayIconPixmapChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::StatusChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(const QString & ) const>(_a, &__StatusNotifierItem::TitleChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(DBusToolTip ) const>(_a, &__StatusNotifierItem::ToolTipChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (__StatusNotifierItem::*)(int ) const>(_a, &__StatusNotifierItem::WindowIdChanged, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
        case 5:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DBusImageList >(); break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DBusToolTip >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->attentionIconName(); break;
        case 1: *reinterpret_cast<DBusImageList*>(_v) = _t->attentionIconPixmap(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->attentionMovieName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->category(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 5: *reinterpret_cast<DBusImageList*>(_v) = _t->iconPixmap(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->iconThemePath(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->itemIsMenu(); break;
        case 9: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->menu(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->overlayIconName(); break;
        case 11: *reinterpret_cast<DBusImageList*>(_v) = _t->overlayIconPixmap(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 14: *reinterpret_cast<DBusToolTip*>(_v) = _t->toolTip(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->windowId(); break;
        default: break;
        }
    }
}

const QMetaObject *__StatusNotifierItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__StatusNotifierItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20__StatusNotifierItemE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __StatusNotifierItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void __StatusNotifierItem::NewAttentionIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void __StatusNotifierItem::NewIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void __StatusNotifierItem::NewOverlayIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void __StatusNotifierItem::NewStatus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __StatusNotifierItem::NewTitle()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void __StatusNotifierItem::NewToolTip()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void __StatusNotifierItem::AttentionIconNameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __StatusNotifierItem::AttentionIconPixmapChanged(DBusImageList _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __StatusNotifierItem::AttentionMovieNameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __StatusNotifierItem::CategoryChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __StatusNotifierItem::IconNameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __StatusNotifierItem::IconPixmapChanged(DBusImageList _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __StatusNotifierItem::IconThemePathChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __StatusNotifierItem::IdChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __StatusNotifierItem::ItemIsMenuChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __StatusNotifierItem::MenuChanged(const QDBusObjectPath & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __StatusNotifierItem::OverlayIconNameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __StatusNotifierItem::OverlayIconPixmapChanged(DBusImageList _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void __StatusNotifierItem::StatusChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void __StatusNotifierItem::TitleChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void __StatusNotifierItem::ToolTipChanged(DBusToolTip _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void __StatusNotifierItem::WindowIdChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __StatusNotifierItem *>(this), &staticMetaObject, 21, nullptr, _t1);
}
QT_WARNING_POP
