/****************************************************************************
** Meta object code from reading C++ file 'wirelesscastingmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plugins/dde-network-display-ui/plugins/common/wirelesscastingmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wirelesscastingmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7MonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto Monitor::qt_create_metaobjectdata<qt_meta_tag_ZN7MonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Monitor",
        "stateChanged",
        "",
        "NdSinkState",
        "state",
        "StatusChanged",
        "status",
        "NameChanged",
        "name",
        "stateChangeFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(const NdSinkState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'StatusChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'stateChangeFinished'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Monitor, qt_meta_tag_ZN7MonitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Monitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7MonitorE_t>.metaTypes,
    nullptr
} };

void Monitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Monitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<NdSinkState>>(_a[1]))); break;
        case 1: _t->StatusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->stateChangeFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const NdSinkState )>(_a, &Monitor::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(int )>(_a, &Monitor::StatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const QString & )>(_a, &Monitor::NameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(int )>(_a, &Monitor::stateChangeFinished, 3))
            return;
    }
}

const QMetaObject *Monitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Monitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MonitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Monitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Monitor::stateChanged(const NdSinkState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Monitor::StatusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Monitor::NameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Monitor::stateChangeFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN20WirelessCastingModelE_t {};
} // unnamed namespace

template <> constexpr inline auto WirelessCastingModel::qt_create_metaobjectdata<qt_meta_tag_ZN20WirelessCastingModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WirelessCastingModel",
        "addMonitor",
        "",
        "path",
        "Monitor*",
        "monitor",
        "removeMonitor",
        "stateChanged",
        "CastingState",
        "state",
        "wirelessDevChanged",
        "wirelessDevCheck",
        "SinkListChanged",
        "QList<QDBusObjectPath>",
        "sinkList",
        "MissingCapabilitiesChanged",
        "missingList",
        "AllDevicesChanged",
        "devList",
        "WirelessEnabledChanged",
        "enabled",
        "DeviceEnabled",
        "connectStateChanged",
        "connecting",
        "multiscreensFlagChanged",
        "flag",
        "stateChangeFinished",
        "serviceAvailableChanged",
        "available",
        "handleMonitorStateChanged",
        "Monitor::NdSinkState",
        "onDBusNameOwnerChanged",
        "name",
        "oldOwner",
        "newOwner"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addMonitor'
        QtMocHelpers::SignalData<void(const QString &, Monitor *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'removeMonitor'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(enum CastingState)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'wirelessDevChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'SinkListChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'MissingCapabilitiesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 16 },
        }}),
        // Signal 'AllDevicesChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 18 },
        }}),
        // Signal 'WirelessEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'DeviceEnabled'
        QtMocHelpers::SignalData<void(const QString &, bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'connectStateChanged'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'multiscreensFlagChanged'
        QtMocHelpers::SignalData<void(const bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'stateChangeFinished'
        QtMocHelpers::SignalData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'serviceAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'handleMonitorStateChanged'
        QtMocHelpers::SlotData<void(const Monitor::NdSinkState)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 9 },
        }}),
        // Slot 'onDBusNameOwnerChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 33 }, { QMetaType::QString, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WirelessCastingModel, qt_meta_tag_ZN20WirelessCastingModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WirelessCastingModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20WirelessCastingModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20WirelessCastingModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20WirelessCastingModelE_t>.metaTypes,
    nullptr
} };

void WirelessCastingModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WirelessCastingModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[2]))); break;
        case 1: _t->removeMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<enum CastingState>>(_a[1]))); break;
        case 3: _t->wirelessDevChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->SinkListChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 5: _t->MissingCapabilitiesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 6: _t->AllDevicesChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 7: _t->WirelessEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->DeviceEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->connectStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->multiscreensFlagChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->stateChangeFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->serviceAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->handleMonitorStateChanged((*reinterpret_cast<std::add_pointer_t<Monitor::NdSinkState>>(_a[1]))); break;
        case 14: _t->onDBusNameOwnerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const QString & , Monitor * )>(_a, &WirelessCastingModel::addMonitor, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const QString & )>(_a, &WirelessCastingModel::removeMonitor, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(CastingState )>(_a, &WirelessCastingModel::stateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(bool )>(_a, &WirelessCastingModel::wirelessDevChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const QList<QDBusObjectPath> & )>(_a, &WirelessCastingModel::SinkListChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const QStringList & )>(_a, &WirelessCastingModel::MissingCapabilitiesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const QList<QDBusObjectPath> & )>(_a, &WirelessCastingModel::AllDevicesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(bool )>(_a, &WirelessCastingModel::WirelessEnabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const QString & , bool )>(_a, &WirelessCastingModel::DeviceEnabled, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(bool )>(_a, &WirelessCastingModel::connectStateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(const bool )>(_a, &WirelessCastingModel::multiscreensFlagChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(int )>(_a, &WirelessCastingModel::stateChangeFinished, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessCastingModel::*)(bool )>(_a, &WirelessCastingModel::serviceAvailableChanged, 12))
            return;
    }
}

const QMetaObject *WirelessCastingModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WirelessCastingModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20WirelessCastingModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WirelessCastingModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void WirelessCastingModel::addMonitor(const QString & _t1, Monitor * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void WirelessCastingModel::removeMonitor(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void WirelessCastingModel::stateChanged(CastingState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WirelessCastingModel::wirelessDevChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WirelessCastingModel::SinkListChanged(const QList<QDBusObjectPath> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void WirelessCastingModel::MissingCapabilitiesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void WirelessCastingModel::AllDevicesChanged(const QList<QDBusObjectPath> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void WirelessCastingModel::WirelessEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void WirelessCastingModel::DeviceEnabled(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void WirelessCastingModel::connectStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void WirelessCastingModel::multiscreensFlagChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void WirelessCastingModel::stateChangeFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void WirelessCastingModel::serviceAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
