/****************************************************************************
** Meta object code from reading C++ file 'timedate1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "timedate1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timedate1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeTimedate1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeTimedate1Interface",
        "TimeUpdate",
        "",
        "CanNTPChanged",
        "value",
        "DSTOffsetChanged",
        "LocalRTCChanged",
        "LongDateFormatChanged",
        "LongTimeFormatChanged",
        "NTPChanged",
        "NTPServerChanged",
        "ShortDateFormatChanged",
        "ShortTimeFormatChanged",
        "TimezoneChanged",
        "Use24HourFormatChanged",
        "UserTimezonesChanged",
        "WeekBeginsChanged",
        "WeekdayFormatChanged",
        "AddUserTimezone",
        "QDBusPendingReply<>",
        "in0",
        "AddUserTimezoneQueued",
        "DeleteUserTimezone",
        "DeleteUserTimezoneQueued",
        "GetSampleNTPServers",
        "QDBusPendingReply<QStringList>",
        "GetZoneInfo",
        "QDBusPendingReply<ZoneInfo>",
        "GetZoneList",
        "SetDate",
        "in1",
        "in2",
        "in3",
        "in4",
        "in5",
        "in6",
        "SetDateQueued",
        "SetLocalRTC",
        "SetLocalRTCQueued",
        "SetNTP",
        "SetNTPQueued",
        "SetNTPServer",
        "SetNTPServerQueued",
        "SetTime",
        "SetTimeQueued",
        "SetTimezone",
        "SetTimezoneQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "CanNTP",
        "DSTOffset",
        "LocalRTC",
        "LongDateFormat",
        "LongTimeFormat",
        "NTP",
        "NTPServer",
        "ShortDateFormat",
        "ShortTimeFormat",
        "Timezone",
        "Use24HourFormat",
        "UserTimezones",
        "WeekBegins",
        "WeekdayFormat"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TimeUpdate'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CanNTPChanged'
        QtMocHelpers::SignalData<void(bool) const>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'DSTOffsetChanged'
        QtMocHelpers::SignalData<void(int) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'LocalRTCChanged'
        QtMocHelpers::SignalData<void(bool) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'LongDateFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'LongTimeFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'NTPChanged'
        QtMocHelpers::SignalData<void(bool) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'NTPServerChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'ShortDateFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'ShortTimeFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'TimezoneChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'Use24HourFormatChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'UserTimezonesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'WeekBeginsChanged'
        QtMocHelpers::SignalData<void(int) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'WeekdayFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'AddUserTimezone'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'AddUserTimezoneQueued'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'DeleteUserTimezone'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'DeleteUserTimezoneQueued'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'GetSampleNTPServers'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'GetZoneInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<ZoneInfo>(const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'GetZoneList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(28, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'SetDate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int, int, int, int, int, int)>(29, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
            { QMetaType::Int, 33 }, { QMetaType::Int, 34 }, { QMetaType::Int, 35 },
        }}),
        // Slot 'SetDateQueued'
        QtMocHelpers::SlotData<void(int, int, int, int, int, int, int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
            { QMetaType::Int, 33 }, { QMetaType::Int, 34 }, { QMetaType::Int, 35 },
        }}),
        // Slot 'SetLocalRTC'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool, bool)>(37, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Bool, 20 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'SetLocalRTCQueued'
        QtMocHelpers::SlotData<void(bool, bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'SetNTP'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(39, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'SetNTPQueued'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'SetNTPServer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(41, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'SetNTPServerQueued'
        QtMocHelpers::SlotData<void(const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'SetTime'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong, bool)>(43, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::LongLong, 20 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'SetTimeQueued'
        QtMocHelpers::SlotData<void(qlonglong, bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 20 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'SetTimezone'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'SetTimezoneQueued'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 49, 50 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 55 }, { 0x80000000 | 56, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanNTP'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'DSTOffset'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'LocalRTC'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'LongDateFormat'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'LongTimeFormat'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'NTP'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'NTPServer'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'ShortDateFormat'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'ShortTimeFormat'
        QtMocHelpers::PropertyData<int>(65, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'Timezone'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'Use24HourFormat'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'UserTimezones'
        QtMocHelpers::PropertyData<QStringList>(68, QMetaType::QStringList, QMC::DefaultPropertyFlags, 12),
        // property 'WeekBegins'
        QtMocHelpers::PropertyData<int>(69, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'WeekdayFormat'
        QtMocHelpers::PropertyData<int>(70, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeTimedate1Interface, qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeTimedate1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeTimedate1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeTimedate1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TimeUpdate(); break;
        case 1: _t->CanNTPChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->DSTOffsetChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->LocalRTCChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->LongDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->LongTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->NTPChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->NTPServerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->ShortDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->ShortTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->TimezoneChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->Use24HourFormatChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->UserTimezonesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->WeekBeginsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->WeekdayFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: { QDBusPendingReply<> _r = _t->AddUserTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->AddUserTimezoneQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: { QDBusPendingReply<> _r = _t->DeleteUserTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->DeleteUserTimezoneQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: { QDBusPendingReply<QStringList> _r = _t->GetSampleNTPServers();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<ZoneInfo> _r = _t->GetZoneInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ZoneInfo>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QStringList> _r = _t->GetZoneList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->SetDate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->SetDateQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 24: { QDBusPendingReply<> _r = _t->SetLocalRTC((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->SetLocalRTCQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: { QDBusPendingReply<> _r = _t->SetNTP((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->SetNTPQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: { QDBusPendingReply<> _r = _t->SetNTPServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->SetNTPServerQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: { QDBusPendingReply<> _r = _t->SetTime((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->SetTimeQueued((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 32: { QDBusPendingReply<> _r = _t->SetTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->SetTimezoneQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 35: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 36: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)()>(_a, &__OrgDeepinDdeTimedate1Interface::TimeUpdate, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeTimedate1Interface::CanNTPChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::DSTOffsetChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeTimedate1Interface::LocalRTCChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::LongDateFormatChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::LongTimeFormatChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeTimedate1Interface::NTPChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeTimedate1Interface::NTPServerChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::ShortDateFormatChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::ShortTimeFormatChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeTimedate1Interface::TimezoneChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeTimedate1Interface::Use24HourFormatChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(const QStringList & ) const>(_a, &__OrgDeepinDdeTimedate1Interface::UserTimezonesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::WeekBeginsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeTimedate1Interface::*)(int ) const>(_a, &__OrgDeepinDdeTimedate1Interface::WeekdayFormatChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canNTP(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->dSTOffset(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->localRTC(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->longDateFormat(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->longTimeFormat(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->nTP(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->nTPServer(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->shortDateFormat(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->shortTimeFormat(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->timezone(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->use24HourFormat(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->userTimezones(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->weekBegins(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->weekdayFormat(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setDSTOffset(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setLongDateFormat(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setLongTimeFormat(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setShortDateFormat(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setShortTimeFormat(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setUse24HourFormat(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setWeekBegins(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setWeekdayFormat(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeTimedate1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeTimedate1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32__OrgDeepinDdeTimedate1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeTimedate1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeTimedate1Interface::TimeUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void __OrgDeepinDdeTimedate1Interface::CanNTPChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeTimedate1Interface::DSTOffsetChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeTimedate1Interface::LocalRTCChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeTimedate1Interface::LongDateFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeTimedate1Interface::LongTimeFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeTimedate1Interface::NTPChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdeTimedate1Interface::NTPServerChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdeTimedate1Interface::ShortDateFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __OrgDeepinDdeTimedate1Interface::ShortTimeFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __OrgDeepinDdeTimedate1Interface::TimezoneChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __OrgDeepinDdeTimedate1Interface::Use24HourFormatChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __OrgDeepinDdeTimedate1Interface::UserTimezonesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __OrgDeepinDdeTimedate1Interface::WeekBeginsChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __OrgDeepinDdeTimedate1Interface::WeekdayFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeTimedate1Interface *>(this), &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
