/****************************************************************************
** Meta object code from reading C++ file 'adapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plugins/dde-dock/bluetooth/componments/adapter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'adapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7AdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto Adapter::qt_create_metaobjectdata<qt_meta_tag_ZN7AdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Adapter",
        "nameChanged",
        "",
        "name",
        "deviceAdded",
        "const Device*",
        "device",
        "deviceRemoved",
        "deviceNameUpdated",
        "poweredChanged",
        "powered",
        "discoveringChanged",
        "discover"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(const Device *) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(const Device *) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'deviceNameUpdated'
        QtMocHelpers::SignalData<void(const Device *) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'poweredChanged'
        QtMocHelpers::SignalData<void(const bool) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'discoveringChanged'
        QtMocHelpers::SignalData<void(const bool) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Adapter, qt_meta_tag_ZN7AdapterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Adapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7AdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7AdapterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7AdapterE_t>.metaTypes,
    nullptr
} };

void Adapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Adapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 2: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 3: _t->deviceNameUpdated((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 4: _t->poweredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->discoveringChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const QString & ) const>(_a, &Adapter::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const Device * ) const>(_a, &Adapter::deviceAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const Device * ) const>(_a, &Adapter::deviceRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const Device * ) const>(_a, &Adapter::deviceNameUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const bool ) const>(_a, &Adapter::poweredChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const bool ) const>(_a, &Adapter::discoveringChanged, 5))
            return;
    }
}

const QMetaObject *Adapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Adapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7AdapterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Adapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Adapter::nameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< Adapter *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Adapter::deviceAdded(const Device * _t1)const
{
    QMetaObject::activate<void>(const_cast< Adapter *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Adapter::deviceRemoved(const Device * _t1)const
{
    QMetaObject::activate<void>(const_cast< Adapter *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Adapter::deviceNameUpdated(const Device * _t1)const
{
    QMetaObject::activate<void>(const_cast< Adapter *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Adapter::poweredChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< Adapter *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Adapter::discoveringChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< Adapter *>(this), &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
