/****************************************************************************
** Meta object code from reading C++ file 'traymanager1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "traymanager1interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traymanager1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TrayManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto TrayManager::qt_create_metaobjectdata<qt_meta_tag_ZN11TrayManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrayManager",
        "Added",
        "",
        "id",
        "Changed",
        "Inited",
        "Removed",
        "EnableNotification",
        "QDBusPendingReply<>",
        "win",
        "enabled",
        "GetName",
        "QDBusPendingReply<QString>",
        "Manage",
        "QDBusPendingReply<bool>",
        "TrayIcons",
        "TrayList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Added'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(uint)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'Inited'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Removed'
        QtMocHelpers::SignalData<void(uint)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'EnableNotification'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, bool)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::UInt, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'GetName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(uint)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::UInt, 9 },
        }}),
        // Slot 'Manage'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'TrayIcons'
        QtMocHelpers::PropertyData<TrayList>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TrayManager, qt_meta_tag_ZN11TrayManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TrayManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TrayManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TrayManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TrayManagerE_t>.metaTypes,
    nullptr
} };

void TrayManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrayManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Added((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->Changed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->Inited(); break;
        case 3: _t->Removed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: { QDBusPendingReply<> _r = _t->EnableNotification((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QString> _r = _t->GetName((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->Manage();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrayManager::*)(uint )>(_a, &TrayManager::Added, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager::*)(uint )>(_a, &TrayManager::Changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager::*)()>(_a, &TrayManager::Inited, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager::*)(uint )>(_a, &TrayManager::Removed, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TrayList*>(_v) = _t->trayIcons(); break;
        default: break;
        }
    }
}

const QMetaObject *TrayManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrayManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TrayManagerE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int TrayManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TrayManager::Added(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TrayManager::Changed(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TrayManager::Inited()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TrayManager::Removed(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
