/****************************************************************************
** Meta object code from reading C++ file 'bluetooth1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "bluetooth1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetooth1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeBluetooth1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeBluetooth1Interface",
        "AdapterAdded",
        "",
        "adapterJSON",
        "AdapterPropertiesChanged",
        "AdapterRemoved",
        "Cancelled",
        "QDBusObjectPath",
        "device",
        "ConnectFailed",
        "DeviceAdded",
        "devJSON",
        "DevicePropertiesChanged",
        "DeviceRemoved",
        "DisplayPasskey",
        "passkey",
        "entered",
        "DisplayPinCode",
        "pinCode",
        "ObexSessionCreated",
        "sessionPath",
        "ObexSessionProgress",
        "totalSize",
        "transferred",
        "currentIdx",
        "ObexSessionRemoved",
        "RequestAuthorization",
        "RequestConfirmation",
        "RequestPasskey",
        "RequestPinCode",
        "TransferCreated",
        "file",
        "transferPath",
        "TransferFailed",
        "errInfo",
        "TransferRemoved",
        "done",
        "CanSendFileChanged",
        "value",
        "DisplaySwitchChanged",
        "StateChanged",
        "TransportableChanged",
        "CancelTransferSession",
        "QDBusPendingReply<>",
        "CancelTransferSessionQueued",
        "ClearUnpairedDevice",
        "ClearUnpairedDeviceQueued",
        "Confirm",
        "accept",
        "ConfirmQueued",
        "ConnectDevice",
        "adapter",
        "ConnectDeviceQueued",
        "DebugInfo",
        "QDBusPendingReply<QString>",
        "DisconnectDevice",
        "DisconnectDeviceQueued",
        "FeedPasskey",
        "FeedPasskeyQueued",
        "FeedPinCode",
        "FeedPinCodeQueued",
        "GetAdapters",
        "GetDevices",
        "RemoveDevice",
        "RemoveDeviceQueued",
        "RequestDiscovery",
        "RequestDiscoveryQueued",
        "SendFiles",
        "QDBusPendingReply<QDBusObjectPath>",
        "files",
        "SetAdapterAlias",
        "alias",
        "SetAdapterAliasQueued",
        "SetAdapterDiscoverable",
        "discoverable",
        "SetAdapterDiscoverableQueued",
        "SetAdapterDiscoverableTimeout",
        "timeout",
        "SetAdapterDiscoverableTimeoutQueued",
        "SetAdapterDiscovering",
        "discovering",
        "SetAdapterDiscoveringQueued",
        "SetAdapterPowered",
        "powered",
        "SetAdapterPoweredQueued",
        "SetDeviceAlias",
        "SetDeviceAliasQueued",
        "SetDeviceTrusted",
        "trusted",
        "SetDeviceTrustedQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "CanSendFile",
        "DisplaySwitch",
        "State",
        "Transportable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AdapterAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AdapterPropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AdapterRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'Cancelled'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'ConnectFailed'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'DeviceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'DevicePropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'DeviceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'DisplayPasskey'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, uint, uint)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::UInt, 15 }, { QMetaType::UInt, 16 },
        }}),
        // Signal 'DisplayPinCode'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'ObexSessionCreated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 20 },
        }}),
        // Signal 'ObexSessionProgress'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, qulonglong, qulonglong, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 20 }, { QMetaType::ULongLong, 22 }, { QMetaType::ULongLong, 23 }, { QMetaType::Int, 24 },
        }}),
        // Signal 'ObexSessionRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 20 },
        }}),
        // Signal 'RequestAuthorization'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'RequestConfirmation'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'RequestPasskey'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'RequestPinCode'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'TransferCreated'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &, const QDBusObjectPath &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { 0x80000000 | 7, 32 }, { 0x80000000 | 7, 20 },
        }}),
        // Signal 'TransferFailed'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &, const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { 0x80000000 | 7, 20 }, { QMetaType::QString, 34 },
        }}),
        // Signal 'TransferRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &, const QDBusObjectPath &, bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { 0x80000000 | 7, 32 }, { 0x80000000 | 7, 20 }, { QMetaType::Bool, 36 },
        }}),
        // Signal 'CanSendFileChanged'
        QtMocHelpers::SignalData<void(bool) const>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'DisplaySwitchChanged'
        QtMocHelpers::SignalData<void(bool) const>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(uint) const>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 38 },
        }}),
        // Signal 'TransportableChanged'
        QtMocHelpers::SignalData<void(bool) const>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'CancelTransferSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(42, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 20 },
        }}),
        // Slot 'CancelTransferSessionQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 20 },
        }}),
        // Slot 'ClearUnpairedDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(45, 2, QMC::AccessPublic, 0x80000000 | 43),
        // Slot 'ClearUnpairedDeviceQueued'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Confirm'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(47, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 48 },
        }}),
        // Slot 'ConfirmQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 48 },
        }}),
        // Slot 'ConnectDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QDBusObjectPath &)>(50, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 51 },
        }}),
        // Slot 'ConnectDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 51 },
        }}),
        // Slot 'DebugInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(53, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'DisconnectDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(55, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'DisconnectDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'FeedPasskey'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool, uint)>(57, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 48 }, { QMetaType::UInt, 15 },
        }}),
        // Slot 'FeedPasskeyQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool, uint)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 48 }, { QMetaType::UInt, 15 },
        }}),
        // Slot 'FeedPinCode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool, const QString &)>(59, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 48 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'FeedPinCodeQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool, const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 48 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'GetAdapters'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(61, 2, QMC::AccessPublic, 0x80000000 | 54),
        // Slot 'GetDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QDBusObjectPath &)>(62, 2, QMC::AccessPublic, 0x80000000 | 54, {{
            { 0x80000000 | 7, 51 },
        }}),
        // Slot 'RemoveDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QDBusObjectPath &)>(63, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'RemoveDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'RequestDiscovery'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(65, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 },
        }}),
        // Slot 'RequestDiscoveryQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 },
        }}),
        // Slot 'SendFiles'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QStringList &)>(67, 2, QMC::AccessPublic, 0x80000000 | 68, {{
            { QMetaType::QString, 8 }, { QMetaType::QStringList, 69 },
        }}),
        // Slot 'SetAdapterAlias'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QString &)>(70, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 }, { QMetaType::QString, 71 },
        }}),
        // Slot 'SetAdapterAliasQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 }, { QMetaType::QString, 71 },
        }}),
        // Slot 'SetAdapterDiscoverable'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(73, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 }, { QMetaType::Bool, 74 },
        }}),
        // Slot 'SetAdapterDiscoverableQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 }, { QMetaType::Bool, 74 },
        }}),
        // Slot 'SetAdapterDiscoverableTimeout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, uint)>(76, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 }, { QMetaType::UInt, 77 },
        }}),
        // Slot 'SetAdapterDiscoverableTimeoutQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, uint)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 }, { QMetaType::UInt, 77 },
        }}),
        // Slot 'SetAdapterDiscovering'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(79, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 }, { QMetaType::Bool, 80 },
        }}),
        // Slot 'SetAdapterDiscoveringQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 }, { QMetaType::Bool, 80 },
        }}),
        // Slot 'SetAdapterPowered'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(82, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 51 }, { QMetaType::Bool, 83 },
        }}),
        // Slot 'SetAdapterPoweredQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 51 }, { QMetaType::Bool, 83 },
        }}),
        // Slot 'SetDeviceAlias'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QString &)>(85, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 71 },
        }}),
        // Slot 'SetDeviceAliasQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 71 },
        }}),
        // Slot 'SetDeviceTrusted'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(87, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 88 },
        }}),
        // Slot 'SetDeviceTrustedQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 88 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 91 }, { 0x80000000 | 92, 93 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(94, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 98 }, { 0x80000000 | 99, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanSendFile'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'DisplaySwitch'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'State'
        QtMocHelpers::PropertyData<uint>(102, QMetaType::UInt, QMC::DefaultPropertyFlags, 22),
        // property 'Transportable'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags, 23),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeBluetooth1Interface, qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeBluetooth1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeBluetooth1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeBluetooth1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AdapterAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->AdapterPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->AdapterRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->Cancelled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 4: _t->ConnectFailed((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 5: _t->DeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->DevicePropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->DeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->DisplayPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 9: _t->DisplayPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->ObexSessionCreated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 11: _t->ObexSessionProgress((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 12: _t->ObexSessionRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 13: _t->RequestAuthorization((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 14: _t->RequestConfirmation((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->RequestPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 16: _t->RequestPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 17: _t->TransferCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3]))); break;
        case 18: _t->TransferFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->TransferRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 20: _t->CanSendFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->DisplaySwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 23: _t->TransportableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: { QDBusPendingReply<> _r = _t->CancelTransferSession((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->CancelTransferSessionQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 26: { QDBusPendingReply<> _r = _t->ClearUnpairedDevice();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->ClearUnpairedDeviceQueued(); break;
        case 28: { QDBusPendingReply<> _r = _t->Confirm((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->ConfirmQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 30: { QDBusPendingReply<> _r = _t->ConnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->ConnectDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 32: { QDBusPendingReply<QString> _r = _t->DebugInfo();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<> _r = _t->DisconnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->DisconnectDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 35: { QDBusPendingReply<> _r = _t->FeedPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->FeedPasskeyQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 37: { QDBusPendingReply<> _r = _t->FeedPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->FeedPinCodeQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 39: { QDBusPendingReply<QString> _r = _t->GetAdapters();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<QString> _r = _t->GetDevices((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->RemoveDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->RemoveDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 43: { QDBusPendingReply<> _r = _t->RequestDiscovery((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->RequestDiscoveryQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 45: { QDBusPendingReply<QDBusObjectPath> _r = _t->SendFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<> _r = _t->SetAdapterAlias((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->SetAdapterAliasQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 48: { QDBusPendingReply<> _r = _t->SetAdapterDiscoverable((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->SetAdapterDiscoverableQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 50: { QDBusPendingReply<> _r = _t->SetAdapterDiscoverableTimeout((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->SetAdapterDiscoverableTimeoutQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 52: { QDBusPendingReply<> _r = _t->SetAdapterDiscovering((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->SetAdapterDiscoveringQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 54: { QDBusPendingReply<> _r = _t->SetAdapterPowered((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->SetAdapterPoweredQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 56: { QDBusPendingReply<> _r = _t->SetDeviceAlias((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->SetDeviceAliasQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 58: { QDBusPendingReply<> _r = _t->SetDeviceTrusted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->SetDeviceTrustedQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 60: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 61: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 62: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::AdapterAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::AdapterPropertiesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::AdapterRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::Cancelled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::ConnectFailed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::DeviceAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::DevicePropertiesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::DeviceRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & , uint , uint )>(_a, &__OrgDeepinDdeBluetooth1Interface::DisplayPasskey, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & , const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::DisplayPinCode, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::ObexSessionCreated, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & , qulonglong , qulonglong , int )>(_a, &__OrgDeepinDdeBluetooth1Interface::ObexSessionProgress, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::ObexSessionRemoved, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::RequestAuthorization, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & , const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::RequestConfirmation, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::RequestPasskey, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::RequestPinCode, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & , const QDBusObjectPath & , const QDBusObjectPath & )>(_a, &__OrgDeepinDdeBluetooth1Interface::TransferCreated, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & , const QDBusObjectPath & , const QString & )>(_a, &__OrgDeepinDdeBluetooth1Interface::TransferFailed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(const QString & , const QDBusObjectPath & , const QDBusObjectPath & , bool )>(_a, &__OrgDeepinDdeBluetooth1Interface::TransferRemoved, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeBluetooth1Interface::CanSendFileChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeBluetooth1Interface::DisplaySwitchChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(uint ) const>(_a, &__OrgDeepinDdeBluetooth1Interface::StateChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeBluetooth1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeBluetooth1Interface::TransportableChanged, 23))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canSendFile(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->displaySwitch(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->state(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->transportable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setDisplaySwitch(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeBluetooth1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeBluetooth1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33__OrgDeepinDdeBluetooth1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeBluetooth1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 63)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 63;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 63)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 63;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeBluetooth1Interface::AdapterAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdeBluetooth1Interface::AdapterPropertiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeBluetooth1Interface::AdapterRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeBluetooth1Interface::Cancelled(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeBluetooth1Interface::ConnectFailed(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeBluetooth1Interface::DeviceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeBluetooth1Interface::DevicePropertiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdeBluetooth1Interface::DeviceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdeBluetooth1Interface::DisplayPasskey(const QDBusObjectPath & _t1, uint _t2, uint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void __OrgDeepinDdeBluetooth1Interface::DisplayPinCode(const QDBusObjectPath & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void __OrgDeepinDdeBluetooth1Interface::ObexSessionCreated(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __OrgDeepinDdeBluetooth1Interface::ObexSessionProgress(const QDBusObjectPath & _t1, qulonglong _t2, qulonglong _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 12
void __OrgDeepinDdeBluetooth1Interface::ObexSessionRemoved(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __OrgDeepinDdeBluetooth1Interface::RequestAuthorization(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __OrgDeepinDdeBluetooth1Interface::RequestConfirmation(const QDBusObjectPath & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void __OrgDeepinDdeBluetooth1Interface::RequestPasskey(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __OrgDeepinDdeBluetooth1Interface::RequestPinCode(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __OrgDeepinDdeBluetooth1Interface::TransferCreated(const QString & _t1, const QDBusObjectPath & _t2, const QDBusObjectPath & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void __OrgDeepinDdeBluetooth1Interface::TransferFailed(const QString & _t1, const QDBusObjectPath & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3);
}

// SIGNAL 19
void __OrgDeepinDdeBluetooth1Interface::TransferRemoved(const QString & _t1, const QDBusObjectPath & _t2, const QDBusObjectPath & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 20
void __OrgDeepinDdeBluetooth1Interface::CanSendFileChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeBluetooth1Interface *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void __OrgDeepinDdeBluetooth1Interface::DisplaySwitchChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeBluetooth1Interface *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void __OrgDeepinDdeBluetooth1Interface::StateChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeBluetooth1Interface *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void __OrgDeepinDdeBluetooth1Interface::TransportableChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeBluetooth1Interface *>(this), &staticMetaObject, 23, nullptr, _t1);
}
QT_WARNING_POP
