/****************************************************************************
** Meta object code from reading C++ file 'plugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/tray-wayland-integration/plugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Plugin11EmbedPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugin::EmbedPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN6Plugin11EmbedPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugin::EmbedPlugin",
        "eventMessage",
        "",
        "msg",
        "eventGeometry",
        "QRect",
        "geometry",
        "contentMarginChanged",
        "int32_t",
        "spacing",
        "dockPositionChanged",
        "uint32_t",
        "position",
        "dockColorThemeChanged",
        "colorType",
        "pluginSupportFlagChanged",
        "dccIconChanged",
        "dccIcon",
        "pluginPosChanged",
        "QPoint",
        "point",
        "itemKeyChanged",
        "pluginIdChanged",
        "pluginTypeChanged",
        "pluginFlagsChanged",
        "pluginSizePolicyChanged",
        "xembedWindowMoved",
        "requestMessage",
        "requestMoveXembedWindow",
        "xembedWinId",
        "pluginRecvMouseEvent",
        "type",
        "rawGlobalPosChanged",
        "pluginRequestShutdown",
        "closeQuickPanel",
        "itemKey",
        "pluginId",
        "pluginType",
        "pluginFlags",
        "pluginSizePolicy",
        "rawGlobalPos",
        "PluginType",
        "Tray",
        "Fixed",
        "Quick"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'eventMessage'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'eventGeometry'
        QtMocHelpers::SignalData<void(const QRect &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'contentMarginChanged'
        QtMocHelpers::SignalData<void(int32_t)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'dockPositionChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'dockColorThemeChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 14 },
        }}),
        // Signal 'pluginSupportFlagChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'dccIconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'pluginPosChanged'
        QtMocHelpers::SignalData<void(const QPoint &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'itemKeyChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginIdChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginTypeChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginFlagsChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginSizePolicyChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xembedWindowMoved'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestMessage'
        QtMocHelpers::SignalData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'requestMoveXembedWindow'
        QtMocHelpers::SignalData<void(uint32_t)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 29 },
        }}),
        // Signal 'pluginRecvMouseEvent'
        QtMocHelpers::SignalData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Signal 'rawGlobalPosChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginRequestShutdown'
        QtMocHelpers::SignalData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'closeQuickPanel'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'itemKey'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'pluginId'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'pluginType'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'pluginFlags'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'pluginSizePolicy'
        QtMocHelpers::PropertyData<uint32_t>(39, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'rawGlobalPos'
        QtMocHelpers::PropertyData<QPoint>(40, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'dccIcon'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PluginType'
        QtMocHelpers::EnumData<enum PluginType>(41, 41, QMC::EnumFlags{}).add({
            {   42, PluginType::Tray },
            {   43, PluginType::Fixed },
            {   44, PluginType::Quick },
        }),
    };
    return QtMocHelpers::metaObjectData<EmbedPlugin, qt_meta_tag_ZN6Plugin11EmbedPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugin::EmbedPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin11EmbedPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin11EmbedPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plugin11EmbedPluginE_t>.metaTypes,
    nullptr
} };

void Plugin::EmbedPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EmbedPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->eventMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->eventGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 2: _t->contentMarginChanged((*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[1]))); break;
        case 3: _t->dockPositionChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 4: _t->dockColorThemeChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 5: _t->pluginSupportFlagChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->dccIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->pluginPosChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->itemKeyChanged(); break;
        case 9: _t->pluginIdChanged(); break;
        case 10: _t->pluginTypeChanged(); break;
        case 11: _t->pluginFlagsChanged(); break;
        case 12: _t->pluginSizePolicyChanged(); break;
        case 13: _t->xembedWindowMoved(); break;
        case 14: _t->requestMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->requestMoveXembedWindow((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 16: _t->pluginRecvMouseEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->rawGlobalPosChanged(); break;
        case 18: _t->pluginRequestShutdown((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->closeQuickPanel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(const QString & )>(_a, &EmbedPlugin::eventMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(const QRect & )>(_a, &EmbedPlugin::eventGeometry, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(int32_t )>(_a, &EmbedPlugin::contentMarginChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(uint32_t )>(_a, &EmbedPlugin::dockPositionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(uint32_t )>(_a, &EmbedPlugin::dockColorThemeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(bool )>(_a, &EmbedPlugin::pluginSupportFlagChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(const QString & )>(_a, &EmbedPlugin::dccIconChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(const QPoint & )>(_a, &EmbedPlugin::pluginPosChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::itemKeyChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::pluginIdChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::pluginTypeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::pluginFlagsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::pluginSizePolicyChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::xembedWindowMoved, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(const QString & )>(_a, &EmbedPlugin::requestMessage, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(uint32_t )>(_a, &EmbedPlugin::requestMoveXembedWindow, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(int )>(_a, &EmbedPlugin::pluginRecvMouseEvent, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::rawGlobalPosChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)(const QString & )>(_a, &EmbedPlugin::pluginRequestShutdown, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmbedPlugin::*)()>(_a, &EmbedPlugin::closeQuickPanel, 19))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->itemKey(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->pluginId(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->pluginType(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->pluginFlags(); break;
        case 4: *reinterpret_cast<uint32_t*>(_v) = _t->pluginSizePolicy(); break;
        case 5: *reinterpret_cast<QPoint*>(_v) = _t->rawGlobalPos(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->dccIcon(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setItemKey(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPluginId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setPluginType(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setPluginFlags(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setPluginSizePolicy(*reinterpret_cast<uint32_t*>(_v)); break;
        case 5: _t->setRawGlobalPos(*reinterpret_cast<QPoint*>(_v)); break;
        case 6: _t->setDccIcon(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plugin::EmbedPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugin::EmbedPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin11EmbedPluginE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plugin::EmbedPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Plugin::EmbedPlugin::eventMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Plugin::EmbedPlugin::eventGeometry(const QRect & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Plugin::EmbedPlugin::contentMarginChanged(int32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plugin::EmbedPlugin::dockPositionChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Plugin::EmbedPlugin::dockColorThemeChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Plugin::EmbedPlugin::pluginSupportFlagChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Plugin::EmbedPlugin::dccIconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Plugin::EmbedPlugin::pluginPosChanged(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Plugin::EmbedPlugin::itemKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Plugin::EmbedPlugin::pluginIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Plugin::EmbedPlugin::pluginTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Plugin::EmbedPlugin::pluginFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Plugin::EmbedPlugin::pluginSizePolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Plugin::EmbedPlugin::xembedWindowMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Plugin::EmbedPlugin::requestMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Plugin::EmbedPlugin::requestMoveXembedWindow(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Plugin::EmbedPlugin::pluginRecvMouseEvent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Plugin::EmbedPlugin::rawGlobalPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Plugin::EmbedPlugin::pluginRequestShutdown(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Plugin::EmbedPlugin::closeQuickPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}
namespace {
struct qt_meta_tag_ZN6Plugin11PluginPopupE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugin::PluginPopup::qt_create_metaobjectdata<qt_meta_tag_ZN6Plugin11PluginPopupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugin::PluginPopup",
        "eventGeometry",
        "",
        "QRect",
        "geometry",
        "itemKeyChanged",
        "pluginIdChanged",
        "popupTypeChanged",
        "xChanged",
        "yChanged",
        "pluginPosChanged",
        "QPoint",
        "point",
        "requestSetCursor",
        "cursorShape",
        "itemKey",
        "pluginId",
        "popupType",
        "x",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'eventGeometry'
        QtMocHelpers::SignalData<void(const QRect &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'itemKeyChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginIdChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'popupTypeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginPosChanged'
        QtMocHelpers::SignalData<void(const QPoint &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'requestSetCursor'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'itemKey'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'pluginId'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'popupType'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'x'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'y'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginPopup, qt_meta_tag_ZN6Plugin11PluginPopupE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugin::PluginPopup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin11PluginPopupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin11PluginPopupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plugin11PluginPopupE_t>.metaTypes,
    nullptr
} };

void Plugin::PluginPopup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginPopup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->eventGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 1: _t->itemKeyChanged(); break;
        case 2: _t->pluginIdChanged(); break;
        case 3: _t->popupTypeChanged(); break;
        case 4: _t->xChanged(); break;
        case 5: _t->yChanged(); break;
        case 6: _t->pluginPosChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 7: _t->requestSetCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)(const QRect & )>(_a, &PluginPopup::eventGeometry, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::itemKeyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::pluginIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::popupTypeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::xChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::yChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)(const QPoint & )>(_a, &PluginPopup::pluginPosChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)(int )>(_a, &PluginPopup::requestSetCursor, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->itemKey(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->pluginId(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->popupType(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->x(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->y(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setItemKey(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPluginId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setPopupType(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setX(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setY(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plugin::PluginPopup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugin::PluginPopup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin11PluginPopupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plugin::PluginPopup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Plugin::PluginPopup::eventGeometry(const QRect & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Plugin::PluginPopup::itemKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Plugin::PluginPopup::pluginIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Plugin::PluginPopup::popupTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Plugin::PluginPopup::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Plugin::PluginPopup::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Plugin::PluginPopup::pluginPosChanged(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Plugin::PluginPopup::requestSetCursor(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto Plugin::PlatformInterfaceProxy::qt_create_metaobjectdata<qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plugin::PlatformInterfaceProxy",
        "fontNameChanged",
        "",
        "fontName",
        "fontPointSizeChanged",
        "fontPointSize",
        "activeColorChanged",
        "QColor",
        "activeColor",
        "darkActiveColorChanged",
        "themeNameChanged",
        "themeName",
        "iconThemeNameChanged",
        "iconThemeName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontNameChanged'
        QtMocHelpers::SignalData<void(QByteArray)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Signal 'fontPointSizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 5 },
        }}),
        // Signal 'activeColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'darkActiveColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'themeNameChanged'
        QtMocHelpers::SignalData<void(QByteArray)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 11 },
        }}),
        // Signal 'iconThemeNameChanged'
        QtMocHelpers::SignalData<void(QByteArray)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlatformInterfaceProxy, qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plugin::PlatformInterfaceProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t>.metaTypes,
    nullptr
} };

void Plugin::PlatformInterfaceProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlatformInterfaceProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontNameChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 1: _t->fontPointSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->activeColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 3: _t->darkActiveColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->themeNameChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 5: _t->iconThemeNameChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlatformInterfaceProxy::*)(QByteArray )>(_a, &PlatformInterfaceProxy::fontNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformInterfaceProxy::*)(qreal )>(_a, &PlatformInterfaceProxy::fontPointSizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformInterfaceProxy::*)(QColor )>(_a, &PlatformInterfaceProxy::activeColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformInterfaceProxy::*)(QColor )>(_a, &PlatformInterfaceProxy::darkActiveColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformInterfaceProxy::*)(QByteArray )>(_a, &PlatformInterfaceProxy::themeNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformInterfaceProxy::*)(QByteArray )>(_a, &PlatformInterfaceProxy::iconThemeNameChanged, 5))
            return;
    }
}

const QMetaObject *Plugin::PlatformInterfaceProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plugin::PlatformInterfaceProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plugin22PlatformInterfaceProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plugin::PlatformInterfaceProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Plugin::PlatformInterfaceProxy::fontNameChanged(QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Plugin::PlatformInterfaceProxy::fontPointSizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Plugin::PlatformInterfaceProxy::activeColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plugin::PlatformInterfaceProxy::darkActiveColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Plugin::PlatformInterfaceProxy::themeNameChanged(QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Plugin::PlatformInterfaceProxy::iconThemeNameChanged(QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
