/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -c StatusNotifierItem -i api/types/dbustooltip.h -p statusnotifieriteminterface /build/deepin-tray-loader/src/dde-tray-loader/plugins/application-tray/api/dbus/org.kde.StatusNotifierItem.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef STATUSNOTIFIERITEMINTERFACE_H
#define STATUSNOTIFIERITEMINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>
#include "api/types/dbustooltip.h"

#include "types/dbusimagelist.h"
#include "types/dbustooltip.h"

/*
 * Proxy class for interface org.kde.StatusNotifierItem
 */
class __StatusNotifierItemPrivate;
class __StatusNotifierItem : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.kde.StatusNotifierItem"; }

public:
    explicit __StatusNotifierItem(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__StatusNotifierItem();

    Q_PROPERTY(QString AttentionIconName READ attentionIconName NOTIFY AttentionIconNameChanged)
    QString attentionIconName();

    Q_PROPERTY(DBusImageList AttentionIconPixmap READ attentionIconPixmap NOTIFY AttentionIconPixmapChanged)
    DBusImageList attentionIconPixmap();

    Q_PROPERTY(QString AttentionMovieName READ attentionMovieName NOTIFY AttentionMovieNameChanged)
    QString attentionMovieName();

    Q_PROPERTY(QString Category READ category NOTIFY CategoryChanged)
    QString category();

    Q_PROPERTY(QString IconName READ iconName NOTIFY IconNameChanged)
    QString iconName();

    Q_PROPERTY(DBusImageList IconPixmap READ iconPixmap NOTIFY IconPixmapChanged)
    DBusImageList iconPixmap();

    Q_PROPERTY(QString IconThemePath READ iconThemePath NOTIFY IconThemePathChanged)
    QString iconThemePath();

    Q_PROPERTY(QString Id READ id NOTIFY IdChanged)
    QString id();

    Q_PROPERTY(bool ItemIsMenu READ itemIsMenu NOTIFY ItemIsMenuChanged)
    bool itemIsMenu();

    Q_PROPERTY(QDBusObjectPath Menu READ menu NOTIFY MenuChanged)
    QDBusObjectPath menu();

    Q_PROPERTY(QString OverlayIconName READ overlayIconName NOTIFY OverlayIconNameChanged)
    QString overlayIconName();

    Q_PROPERTY(DBusImageList OverlayIconPixmap READ overlayIconPixmap NOTIFY OverlayIconPixmapChanged)
    DBusImageList overlayIconPixmap();

    Q_PROPERTY(QString Status READ status NOTIFY StatusChanged)
    QString status();

    Q_PROPERTY(QString Title READ title NOTIFY TitleChanged)
    QString title();

    Q_PROPERTY(DBusToolTip ToolTip READ toolTip NOTIFY ToolTipChanged)
    DBusToolTip toolTip();

    Q_PROPERTY(int WindowId READ windowId NOTIFY WindowIdChanged)
    int windowId();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Activate(int x, int y)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y);
        return asyncCallWithArgumentList(QStringLiteral("Activate"), argumentList);
    }

    inline void ActivateQueued(int x, int y)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y);

        CallQueued(QStringLiteral("Activate"), argumentList);
    }


    inline QDBusPendingReply<> ContextMenu(int x, int y)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y);
        return asyncCallWithArgumentList(QStringLiteral("ContextMenu"), argumentList);
    }

    inline void ContextMenuQueued(int x, int y)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y);

        CallQueued(QStringLiteral("ContextMenu"), argumentList);
    }


    inline QDBusPendingReply<> ProvideXdgActivationToken(const QString &token)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(token);
        return asyncCallWithArgumentList(QStringLiteral("ProvideXdgActivationToken"), argumentList);
    }

    inline void ProvideXdgActivationTokenQueued(const QString &token)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(token);

        CallQueued(QStringLiteral("ProvideXdgActivationToken"), argumentList);
    }


    inline QDBusPendingReply<> Scroll(int delta, const QString &orientation)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(delta) << QVariant::fromValue(orientation);
        return asyncCallWithArgumentList(QStringLiteral("Scroll"), argumentList);
    }

    inline void ScrollQueued(int delta, const QString &orientation)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(delta) << QVariant::fromValue(orientation);

        CallQueued(QStringLiteral("Scroll"), argumentList);
    }


    inline QDBusPendingReply<> SecondaryActivate(int x, int y)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y);
        return asyncCallWithArgumentList(QStringLiteral("SecondaryActivate"), argumentList);
    }

    inline void SecondaryActivateQueued(int x, int y)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(x) << QVariant::fromValue(y);

        CallQueued(QStringLiteral("SecondaryActivate"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void NewAttentionIcon();
    void NewIcon();
    void NewOverlayIcon();
    void NewStatus(const QString &status);
    void NewTitle();
    void NewToolTip();
    // begin property changed signals
    void AttentionIconNameChanged(const QString & value) const;
    void AttentionIconPixmapChanged(DBusImageList  value) const;
    void AttentionMovieNameChanged(const QString & value) const;
    void CategoryChanged(const QString & value) const;
    void IconNameChanged(const QString & value) const;
    void IconPixmapChanged(DBusImageList  value) const;
    void IconThemePathChanged(const QString & value) const;
    void IdChanged(const QString & value) const;
    void ItemIsMenuChanged(bool  value) const;
    void MenuChanged(const QDBusObjectPath & value) const;
    void OverlayIconNameChanged(const QString & value) const;
    void OverlayIconPixmapChanged(DBusImageList  value) const;
    void StatusChanged(const QString & value) const;
    void TitleChanged(const QString & value) const;
    void ToolTipChanged(DBusToolTip  value) const;
    void WindowIdChanged(int  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __StatusNotifierItemPrivate *d_ptr;
};

namespace org {
  namespace kde {
    typedef ::__StatusNotifierItem StatusNotifierItem;
  }
}
#endif
