/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.TrayManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TRAYMANAGER1ADAPTOR_H
#define TRAYMANAGER1ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "traymanager1.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.deepin.dde.TrayManager1
 */
class TrayManager1Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.deepin.dde.TrayManager1")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.deepin.dde.TrayManager1\">\n"
"    <method name=\"EnableNotification\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"win\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"enabled\"/>\n"
"    </method>\n"
"    <method name=\"GetName\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"win\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"Manage\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"ok\"/>\n"
"    </method>\n"
"    <signal name=\"Inited\"/>\n"
"    <signal name=\"Added\">\n"
"      <arg type=\"u\" name=\"id\"/>\n"
"    </signal>\n"
"    <signal name=\"Removed\">\n"
"      <arg type=\"u\" name=\"id\"/>\n"
"    </signal>\n"
"    <signal name=\"Changed\">\n"
"      <arg type=\"u\" name=\"id\"/>\n"
"    </signal>\n"
"    <property access=\"read\" type=\"au\" name=\"TrayIcons\">\n"
"      <annotation value=\"TrayList\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n"
"    </property>\n"
"  </interface>\n"
        "")
public:
    TrayManager1Adaptor(TrayManager1 *parent);
    ~TrayManager1Adaptor() override;

    inline TrayManager1 *parent() const
    { return static_cast<TrayManager1 *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(TrayList TrayIcons READ trayIcons)
    TrayList trayIcons() const;

public Q_SLOTS: // METHODS
    void EnableNotification(uint win, bool enabled);
    QString GetName(uint win);
    bool Manage();
Q_SIGNALS: // SIGNALS
    void Added(uint id);
    void Changed(uint id);
    void Inited();
    void Removed(uint id);
};

#endif
