/****************************************************************************
** Meta object code from reading C++ file 'dbusmenuimporter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plugins/libdbusmenuqt/dbusmenuimporter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmenuimporter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DBusMenuImporterE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusMenuImporter::qt_create_metaobjectdata<qt_meta_tag_ZN16DBusMenuImporterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusMenuImporter",
        "menuUpdated",
        "",
        "QMenu*",
        "actionActivationRequested",
        "QAction*",
        "updateMenu",
        "force",
        "menu",
        "sendClickedEvent",
        "slotMenuAboutToShow",
        "slotMenuAboutToHide",
        "slotAboutToShowDBusCallFinished",
        "QDBusPendingCallWatcher*",
        "slotItemActivationRequested",
        "id",
        "timestamp",
        "processPendingLayoutUpdates",
        "slotLayoutUpdated",
        "revision",
        "parentId",
        "slotGetLayoutFinished",
        "slotItemsPropertiesUpdated",
        "DBusMenuItemList",
        "updatedList",
        "DBusMenuItemKeysList",
        "removedList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'menuUpdated'
        QtMocHelpers::SignalData<void(QMenu *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'actionActivationRequested'
        QtMocHelpers::SignalData<void(QAction *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'updateMenu'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'updateMenu'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateMenu'
        QtMocHelpers::SlotData<void(QMenu *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 },
        }}),
        // Slot 'sendClickedEvent'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotMenuAboutToShow'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMenuAboutToHide'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAboutToShowDBusCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotItemActivationRequested'
        QtMocHelpers::SlotData<void(int, uint)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::UInt, 16 },
        }}),
        // Slot 'processPendingLayoutUpdates'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLayoutUpdated'
        QtMocHelpers::SlotData<void(uint, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 19 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'slotGetLayoutFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotItemsPropertiesUpdated'
        QtMocHelpers::SlotData<void(const DBusMenuItemList &, const DBusMenuItemKeysList &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusMenuImporter, qt_meta_tag_ZN16DBusMenuImporterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusMenuImporter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DBusMenuImporterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DBusMenuImporterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DBusMenuImporterE_t>.metaTypes,
    nullptr
} };

void DBusMenuImporter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusMenuImporter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->menuUpdated((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 1: _t->actionActivationRequested((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 2: _t->updateMenu((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->updateMenu(); break;
        case 4: _t->updateMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 5: _t->sendClickedEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->slotMenuAboutToShow(); break;
        case 7: _t->slotMenuAboutToHide(); break;
        case 8: _t->slotAboutToShowDBusCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 9: _t->slotItemActivationRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 10: _t->processPendingLayoutUpdates(); break;
        case 11: _t->slotLayoutUpdated((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->slotGetLayoutFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 13: _t->d->slotItemsPropertiesUpdated((*reinterpret_cast<std::add_pointer_t<DBusMenuItemList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBusMenuItemKeysList>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusMenuImporter::*)(QMenu * )>(_a, &DBusMenuImporter::menuUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMenuImporter::*)(QAction * )>(_a, &DBusMenuImporter::actionActivationRequested, 1))
            return;
    }
}

const QMetaObject *DBusMenuImporter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusMenuImporter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DBusMenuImporterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusMenuImporter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void DBusMenuImporter::menuUpdated(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DBusMenuImporter::actionActivationRequested(QAction * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
