/****************************************************************************
** Meta object code from reading C++ file 'fcitxinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "fcitxinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitxinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21FcitxInputMethodProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto FcitxInputMethodProxy::qt_create_metaobjectdata<qt_meta_tag_ZN21FcitxInputMethodProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FcitxInputMethodProxy",
        "ReloadConfigUI",
        "",
        "ActivateIM",
        "QDBusPendingReply<>",
        "Configure",
        "ConfigureAddon",
        "addon",
        "ConfigureIM",
        "im",
        "CreateIC",
        "QDBusPendingReply<int,uint,uint,uint,uint>",
        "QDBusReply<int>",
        "uint&",
        "keyval1",
        "state1",
        "keyval2",
        "state2",
        "CreateICv2",
        "QDBusPendingReply<int,bool,uint,uint,uint,uint>",
        "appname",
        "bool&",
        "enable",
        "CreateICv3",
        "pid",
        "Exit",
        "GetCurrentIM",
        "QDBusPendingReply<QString>",
        "GetCurrentState",
        "QDBusPendingReply<int>",
        "GetCurrentUI",
        "GetIMAddon",
        "GetIMByIndex",
        "index",
        "InactivateIM",
        "ReloadAddonConfig",
        "ReloadConfig",
        "ResetIMList",
        "Restart",
        "SetCurrentIM",
        "SwitchIM",
        "ToggleIM",
        "CurrentIM",
        "IMList",
        "FcitxQtInputMethodItemList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ReloadConfigUI'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ActivateIM'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'Configure'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(5, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'ConfigureAddon'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(6, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'ConfigureIM'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'CreateIC'
        QtMocHelpers::SlotData<QDBusPendingReply<int,uint,uint,uint,uint>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'CreateIC'
        QtMocHelpers::SlotData<QDBusReply<int>(uint &, uint &, uint &, uint &)>(10, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 }, { 0x80000000 | 13, 16 }, { 0x80000000 | 13, 17 },
        }}),
        // Slot 'CreateICv2'
        QtMocHelpers::SlotData<QDBusPendingReply<int,bool,uint,uint,uint,uint>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'CreateICv2'
        QtMocHelpers::SlotData<QDBusReply<int>(const QString &, bool &, uint &, uint &, uint &, uint &)>(18, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
            { 0x80000000 | 13, 16 }, { 0x80000000 | 13, 17 },
        }}),
        // Slot 'CreateICv3'
        QtMocHelpers::SlotData<QDBusPendingReply<int,bool,uint,uint,uint,uint>(const QString &, int)>(23, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'CreateICv3'
        QtMocHelpers::SlotData<QDBusReply<int>(const QString &, int, bool &, uint &, uint &, uint &, uint &)>(23, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 24 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 13, 14 },
            { 0x80000000 | 13, 15 }, { 0x80000000 | 13, 16 }, { 0x80000000 | 13, 17 },
        }}),
        // Slot 'Exit'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(25, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'GetCurrentIM'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(26, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'GetCurrentState'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(28, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Slot 'GetCurrentUI'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(30, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'GetIMAddon'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'GetIMByIndex'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(int)>(32, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'InactivateIM'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(34, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'ReloadAddonConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'ReloadConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(36, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'ResetIMList'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(37, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'Restart'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(38, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'SetCurrentIM'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'SwitchIM'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(40, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'ToggleIM'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(41, 2, QMC::AccessPublic, 0x80000000 | 4),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CurrentIM'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'IMList'
        QtMocHelpers::PropertyData<FcitxQtInputMethodItemList>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FcitxInputMethodProxy, qt_meta_tag_ZN21FcitxInputMethodProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FcitxInputMethodProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FcitxInputMethodProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FcitxInputMethodProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21FcitxInputMethodProxyE_t>.metaTypes,
    nullptr
} };

void FcitxInputMethodProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FcitxInputMethodProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ReloadConfigUI(); break;
        case 1: { QDBusPendingReply<> _r = _t->ActivateIM();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->Configure();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->ConfigureAddon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->ConfigureIM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<int,uint,uint,uint,uint> _r = _t->CreateIC();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int,uint,uint,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusReply<int> _r = _t->CreateIC((*reinterpret_cast<std::add_pointer_t<uint&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<int,bool,uint,uint,uint,uint> _r = _t->CreateICv2((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int,bool,uint,uint,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusReply<int> _r = _t->CreateICv2((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<int,bool,uint,uint,uint,uint> _r = _t->CreateICv3((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int,bool,uint,uint,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusReply<int> _r = _t->CreateICv3((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->Exit();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QString> _r = _t->GetCurrentIM();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<int> _r = _t->GetCurrentState();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QString> _r = _t->GetCurrentUI();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QString> _r = _t->GetIMAddon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QString> _r = _t->GetIMByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->InactivateIM();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->ReloadAddonConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->ReloadConfig();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->ResetIMList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->Restart();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->SetCurrentIM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SwitchIM();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->ToggleIM();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FcitxInputMethodProxy::*)()>(_a, &FcitxInputMethodProxy::ReloadConfigUI, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FcitxQtInputMethodItemList >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentIM(); break;
        case 1: *reinterpret_cast<FcitxQtInputMethodItemList*>(_v) = _t->iMList(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentIM(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setIMList(*reinterpret_cast<FcitxQtInputMethodItemList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FcitxInputMethodProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FcitxInputMethodProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FcitxInputMethodProxyE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int FcitxInputMethodProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void FcitxInputMethodProxy::ReloadConfigUI()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
