/****************************************************************************
** Meta object code from reading C++ file 'soundcardport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plugins/dde-dock/sound/soundcardport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'soundcardport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13SoundCardPortE_t {};
} // unnamed namespace

template <> constexpr inline auto SoundCardPort::qt_create_metaobjectdata<qt_meta_tag_ZN13SoundCardPortE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SoundCardPort",
        "idChanged",
        "",
        "id",
        "nameChanged",
        "name",
        "cardNameChanged",
        "activityChanged",
        "active",
        "directionChanged",
        "Direction",
        "direction",
        "cardIdChanged",
        "cardId",
        "enabledChanged",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void(QString) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(QString) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'cardNameChanged'
        QtMocHelpers::SignalData<void(QString) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'activityChanged'
        QtMocHelpers::SignalData<void(bool) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'directionChanged'
        QtMocHelpers::SignalData<void(enum Direction) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'cardIdChanged'
        QtMocHelpers::SignalData<void(uint) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 13 },
        }}),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SoundCardPort, qt_meta_tag_ZN13SoundCardPortE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SoundCardPort::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SoundCardPortE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SoundCardPortE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SoundCardPortE_t>.metaTypes,
    nullptr
} };

void SoundCardPort::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SoundCardPort *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cardNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->activityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->directionChanged((*reinterpret_cast<std::add_pointer_t<enum Direction>>(_a[1]))); break;
        case 5: _t->cardIdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(QString ) const>(_a, &SoundCardPort::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(QString ) const>(_a, &SoundCardPort::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(QString ) const>(_a, &SoundCardPort::cardNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(bool ) const>(_a, &SoundCardPort::activityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(Direction ) const>(_a, &SoundCardPort::directionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(uint ) const>(_a, &SoundCardPort::cardIdChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundCardPort::*)(bool )>(_a, &SoundCardPort::enabledChanged, 6))
            return;
    }
}

const QMetaObject *SoundCardPort::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SoundCardPort::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SoundCardPortE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SoundCardPort::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void SoundCardPort::idChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundCardPort *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SoundCardPort::nameChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundCardPort *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SoundCardPort::cardNameChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundCardPort *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SoundCardPort::activityChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundCardPort *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SoundCardPort::directionChanged(Direction _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundCardPort *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SoundCardPort::cardIdChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundCardPort *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SoundCardPort::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
