/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_sessionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plugins/dde-dock/shutdown/dbus/org_deepin_dde_sessionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_sessionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SessionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionManager::qt_create_metaobjectdata<qt_meta_tag_ZN14SessionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionManager",
        "Unlock",
        "",
        "AllowSessionDaemonRun",
        "QDBusPendingReply<bool>",
        "CanHibernate",
        "CanLogout",
        "CanReboot",
        "CanShutdown",
        "CanSuspend",
        "ForceLogout",
        "QDBusPendingReply<>",
        "ForceReboot",
        "ForceShutdown",
        "Logout",
        "PowerOffChoose",
        "Reboot",
        "Register",
        "in0",
        "RequestHibernate",
        "RequestLock",
        "RequestLogout",
        "RequestReboot",
        "RequestShutdown",
        "RequestSuspend",
        "SetLocked",
        "Shutdown",
        "ToggleDebug",
        "CurrentSessionPath",
        "QDBusObjectPath",
        "CurrentUid",
        "Locked",
        "Stage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Unlock'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'AllowSessionDaemonRun'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'CanHibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(5, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'CanLogout'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(6, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'CanReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(7, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'CanShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(8, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'CanSuspend'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(9, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'ForceLogout'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'ForceReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(12, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'ForceShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'Logout'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(14, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'PowerOffChoose'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'Reboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(16, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'Register'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'RequestHibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(19, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'RequestLock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(20, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'RequestLogout'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(21, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'RequestReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(22, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'RequestShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(23, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'RequestSuspend'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(24, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'SetLocked'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(25, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'Shutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(26, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'ToggleDebug'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(27, 2, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CurrentSessionPath'
        QtMocHelpers::PropertyData<QDBusObjectPath>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'CurrentUid'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Stage'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SessionManager, qt_meta_tag_ZN14SessionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SessionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SessionManagerE_t>.metaTypes,
    nullptr
} };

void SessionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Unlock(); break;
        case 1: { QDBusPendingReply<bool> _r = _t->AllowSessionDaemonRun();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<bool> _r = _t->CanHibernate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<bool> _r = _t->CanLogout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->CanReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->CanShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->CanSuspend();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->ForceLogout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->ForceReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->ForceShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->Logout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->PowerOffChoose();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->Reboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->Register((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->RequestHibernate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->RequestLock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->RequestLogout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->RequestReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->RequestShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->RequestSuspend();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->SetLocked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->Shutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->ToggleDebug();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionManager::*)()>(_a, &SessionManager::Unlock, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->currentSessionPath(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentUid(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->stage(); break;
        default: break;
        }
    }
}

const QMetaObject *SessionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int SessionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SessionManager::Unlock()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
