// SPDX-FileCopyrightText: 2024 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#pragma once

#include "plugins-logging-category.h"


namespace Dock
{
namespace Brightness
{
    enum DisplayMode {
        DisplayMode_Custom = 0,
        DisplayMode_Mirror,
        DisplayMode_Externd,
        DisplayMode_Single
    };
}
}

