/* Generated by wayland-scanner 1.25.0 */

/*
 * Copyright © 2024 Uniontech
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

extern const struct wl_interface plugin_interface;
extern const struct wl_interface plugin_popup_interface;
extern const struct wl_interface wl_callback_interface;
extern const struct wl_interface wl_surface_interface;

static const struct wl_interface *plugin_manager_v1_types[] = {
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	&plugin_popup_interface,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	&plugin_interface,
	NULL,
	NULL,
	NULL,
	&wl_callback_interface,
};

static const struct wl_message plugin_manager_v1_requests[] = {
	{ "destroy", "", plugin_manager_v1_types + 0 },
	{ "request_message", "sss", plugin_manager_v1_types + 0 },
	{ "create_popup_at", "ssiiion", plugin_manager_v1_types + 4 },
	{ "create_plugin", "sssiiion", plugin_manager_v1_types + 11 },
	{ "move_xembed_window", "ussn", plugin_manager_v1_types + 19 },
};

static const struct wl_message plugin_manager_v1_events[] = {
	{ "position_changed", "u", plugin_manager_v1_types + 0 },
	{ "color_theme_changed", "u", plugin_manager_v1_types + 0 },
	{ "active_color_changed", "ss", plugin_manager_v1_types + 0 },
	{ "font_changed", "si", plugin_manager_v1_types + 0 },
	{ "theme_changed", "ss", plugin_manager_v1_types + 0 },
	{ "event_message", "s", plugin_manager_v1_types + 0 },
};

WL_EXPORT const struct wl_interface plugin_manager_v1_interface = {
	"plugin_manager_v1", 1,
	5, plugin_manager_v1_requests,
	6, plugin_manager_v1_events,
};

static const struct wl_message plugin_popup_requests[] = {
	{ "destroy", "", plugin_manager_v1_types + 0 },
	{ "set_position", "ii", plugin_manager_v1_types + 0 },
	{ "source_size", "ii", plugin_manager_v1_types + 0 },
	{ "set_cursor", "i", plugin_manager_v1_types + 0 },
};

static const struct wl_message plugin_popup_events[] = {
	{ "close", "", plugin_manager_v1_types + 0 },
	{ "geometry", "iiii", plugin_manager_v1_types + 0 },
};

WL_EXPORT const struct wl_interface plugin_popup_interface = {
	"plugin_popup", 1,
	4, plugin_popup_requests,
	2, plugin_popup_events,
};

static const struct wl_message plugin_requests[] = {
	{ "destroy", "", plugin_manager_v1_types + 0 },
	{ "mouse_event", "i", plugin_manager_v1_types + 0 },
	{ "dcc_icon", "s", plugin_manager_v1_types + 0 },
	{ "request_shutdown", "s", plugin_manager_v1_types + 0 },
	{ "source_size", "ii", plugin_manager_v1_types + 0 },
	{ "close_quick_panel", "", plugin_manager_v1_types + 0 },
};

static const struct wl_message plugin_events[] = {
	{ "close", "", plugin_manager_v1_types + 0 },
	{ "geometry", "iiii", plugin_manager_v1_types + 0 },
	{ "margin", "i", plugin_manager_v1_types + 0 },
	{ "raw_global_pos", "ii", plugin_manager_v1_types + 0 },
};

WL_EXPORT const struct wl_interface plugin_interface = {
	"plugin", 1,
	6, plugin_requests,
	4, plugin_events,
};

