/****************************************************************************
** Meta object code from reading C++ file 'display1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "display1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'display1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeDisplay1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeDisplay1Interface",
        "BrightnessChanged",
        "",
        "BrightnessMap",
        "value",
        "ColorTemperatureManualChanged",
        "ColorTemperatureModeChanged",
        "CurrentCustomIdChanged",
        "CustomIdListChanged",
        "DisplayModeChanged",
        "HasChangedChanged",
        "MaxBacklightBrightnessChanged",
        "MonitorsChanged",
        "QList<QDBusObjectPath>",
        "PrimaryChanged",
        "PrimaryRectChanged",
        "ScreenRect",
        "ScreenHeightChanged",
        "ScreenWidthChanged",
        "TouchMapChanged",
        "TouchscreenMap",
        "TouchscreensChanged",
        "TouchscreenInfoList",
        "TouchscreensV2Changed",
        "TouchscreenInfoList_V2",
        "ApplyChanges",
        "QDBusPendingReply<>",
        "ApplyChangesQueued",
        "AssociateTouch",
        "in0",
        "in1",
        "AssociateTouchQueued",
        "AssociateTouchByUUID",
        "AssociateTouchByUUIDQueued",
        "ChangeBrightness",
        "ChangeBrightnessQueued",
        "DeleteCustomMode",
        "DeleteCustomModeQueued",
        "GetRealDisplayMode",
        "QDBusPendingReply<uchar>",
        "ListOutputNames",
        "QDBusPendingReply<QStringList>",
        "ListOutputsCommonModes",
        "QDBusPendingReply<ResolutionList>",
        "ModifyConfigName",
        "ModifyConfigNameQueued",
        "RefreshBrightness",
        "RefreshBrightnessQueued",
        "Reset",
        "ResetQueued",
        "ResetChanges",
        "ResetChangesQueued",
        "Save",
        "SaveQueued",
        "SetAndSaveBrightness",
        "SetAndSaveBrightnessQueued",
        "SetBrightness",
        "SetBrightnessQueued",
        "SetColorTemperature",
        "SetColorTemperatureQueued",
        "SetMethodAdjustCCT",
        "SetMethodAdjustCCTQueued",
        "SetPrimary",
        "SetPrimaryQueued",
        "SwitchMode",
        "SwitchModeQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Brightness",
        "ColorTemperatureManual",
        "ColorTemperatureMode",
        "CurrentCustomId",
        "CustomIdList",
        "DisplayMode",
        "HasChanged",
        "MaxBacklightBrightness",
        "Monitors",
        "Primary",
        "PrimaryRect",
        "ScreenHeight",
        "ScreenWidth",
        "TouchMap",
        "Touchscreens",
        "TouchscreensV2"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BrightnessChanged'
        QtMocHelpers::SignalData<void(BrightnessMap) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ColorTemperatureManualChanged'
        QtMocHelpers::SignalData<void(int) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'ColorTemperatureModeChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'CurrentCustomIdChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'CustomIdListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void(uchar) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 4 },
        }}),
        // Signal 'HasChangedChanged'
        QtMocHelpers::SignalData<void(bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'MaxBacklightBrightnessChanged'
        QtMocHelpers::SignalData<void(uint) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Signal 'MonitorsChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 4 },
        }}),
        // Signal 'PrimaryChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'PrimaryRectChanged'
        QtMocHelpers::SignalData<void(ScreenRect) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 4 },
        }}),
        // Signal 'ScreenHeightChanged'
        QtMocHelpers::SignalData<void(ushort) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 4 },
        }}),
        // Signal 'ScreenWidthChanged'
        QtMocHelpers::SignalData<void(ushort) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 4 },
        }}),
        // Signal 'TouchMapChanged'
        QtMocHelpers::SignalData<void(TouchscreenMap) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 4 },
        }}),
        // Signal 'TouchscreensChanged'
        QtMocHelpers::SignalData<void(TouchscreenInfoList) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 4 },
        }}),
        // Signal 'TouchscreensV2Changed'
        QtMocHelpers::SignalData<void(TouchscreenInfoList_V2) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 4 },
        }}),
        // Slot 'ApplyChanges'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(25, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'ApplyChangesQueued'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'AssociateTouch'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'AssociateTouchQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'AssociateTouchByUUID'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'AssociateTouchByUUIDQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'ChangeBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(34, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'ChangeBrightnessQueued'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'DeleteCustomMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'DeleteCustomModeQueued'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'GetRealDisplayMode'
        QtMocHelpers::SlotData<QDBusPendingReply<uchar>()>(38, 2, QMC::AccessPublic, 0x80000000 | 39),
        // Slot 'ListOutputNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(40, 2, QMC::AccessPublic, 0x80000000 | 41),
        // Slot 'ListOutputsCommonModes'
        QtMocHelpers::SlotData<QDBusPendingReply<ResolutionList>()>(42, 2, QMC::AccessPublic, 0x80000000 | 43),
        // Slot 'ModifyConfigName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(44, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'ModifyConfigNameQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'RefreshBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(46, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'RefreshBrightnessQueued'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(48, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'ResetQueued'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ResetChanges'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(50, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'ResetChangesQueued'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Save'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(52, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'SaveQueued'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetAndSaveBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, double)>(54, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 }, { QMetaType::Double, 30 },
        }}),
        // Slot 'SetAndSaveBrightnessQueued'
        QtMocHelpers::SlotData<void(const QString &, double)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::Double, 30 },
        }}),
        // Slot 'SetBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, double)>(56, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 }, { QMetaType::Double, 30 },
        }}),
        // Slot 'SetBrightnessQueued'
        QtMocHelpers::SlotData<void(const QString &, double)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::Double, 30 },
        }}),
        // Slot 'SetColorTemperature'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(58, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'SetColorTemperatureQueued'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'SetMethodAdjustCCT'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(60, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'SetMethodAdjustCCTQueued'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'SetPrimary'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(62, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'SetPrimaryQueued'
        QtMocHelpers::SlotData<void(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'SwitchMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uchar, const QString &)>(64, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::UChar, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'SwitchModeQueued'
        QtMocHelpers::SlotData<void(uchar, const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 67 }, { 0x80000000 | 68, 69 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 74 }, { 0x80000000 | 75, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Brightness'
        QtMocHelpers::PropertyData<BrightnessMap>(76, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'ColorTemperatureManual'
        QtMocHelpers::PropertyData<int>(77, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'ColorTemperatureMode'
        QtMocHelpers::PropertyData<int>(78, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'CurrentCustomId'
        QtMocHelpers::PropertyData<QString>(79, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'CustomIdList'
        QtMocHelpers::PropertyData<QStringList>(80, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<uchar>(81, QMetaType::UChar, QMC::DefaultPropertyFlags, 5),
        // property 'HasChanged'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'MaxBacklightBrightness'
        QtMocHelpers::PropertyData<uint>(83, QMetaType::UInt, QMC::DefaultPropertyFlags, 7),
        // property 'Monitors'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(84, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'Primary'
        QtMocHelpers::PropertyData<QString>(85, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'PrimaryRect'
        QtMocHelpers::PropertyData<ScreenRect>(86, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'ScreenHeight'
        QtMocHelpers::PropertyData<ushort>(87, QMetaType::UShort, QMC::DefaultPropertyFlags, 11),
        // property 'ScreenWidth'
        QtMocHelpers::PropertyData<ushort>(88, QMetaType::UShort, QMC::DefaultPropertyFlags, 12),
        // property 'TouchMap'
        QtMocHelpers::PropertyData<TouchscreenMap>(89, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'Touchscreens'
        QtMocHelpers::PropertyData<TouchscreenInfoList>(90, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'TouchscreensV2'
        QtMocHelpers::PropertyData<TouchscreenInfoList_V2>(91, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeDisplay1Interface, qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeDisplay1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeDisplay1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeDisplay1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BrightnessChanged((*reinterpret_cast<std::add_pointer_t<BrightnessMap>>(_a[1]))); break;
        case 1: _t->ColorTemperatureManualChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->ColorTemperatureModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->CurrentCustomIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->CustomIdListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->DisplayModeChanged((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1]))); break;
        case 6: _t->HasChangedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->MaxBacklightBrightnessChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: _t->MonitorsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 9: _t->PrimaryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->PrimaryRectChanged((*reinterpret_cast<std::add_pointer_t<ScreenRect>>(_a[1]))); break;
        case 11: _t->ScreenHeightChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 12: _t->ScreenWidthChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 13: _t->TouchMapChanged((*reinterpret_cast<std::add_pointer_t<TouchscreenMap>>(_a[1]))); break;
        case 14: _t->TouchscreensChanged((*reinterpret_cast<std::add_pointer_t<TouchscreenInfoList>>(_a[1]))); break;
        case 15: _t->TouchscreensV2Changed((*reinterpret_cast<std::add_pointer_t<TouchscreenInfoList_V2>>(_a[1]))); break;
        case 16: { QDBusPendingReply<> _r = _t->ApplyChanges();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->ApplyChangesQueued(); break;
        case 18: { QDBusPendingReply<> _r = _t->AssociateTouch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->AssociateTouchQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: { QDBusPendingReply<> _r = _t->AssociateTouchByUUID((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->AssociateTouchByUUIDQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: { QDBusPendingReply<> _r = _t->ChangeBrightness((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->ChangeBrightnessQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: { QDBusPendingReply<> _r = _t->DeleteCustomMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->DeleteCustomModeQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { QDBusPendingReply<uchar> _r = _t->GetRealDisplayMode();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uchar>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<QStringList> _r = _t->ListOutputNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<ResolutionList> _r = _t->ListOutputsCommonModes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ResolutionList>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<> _r = _t->ModifyConfigName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->ModifyConfigNameQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 31: { QDBusPendingReply<> _r = _t->RefreshBrightness();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->RefreshBrightnessQueued(); break;
        case 33: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->ResetQueued(); break;
        case 35: { QDBusPendingReply<> _r = _t->ResetChanges();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->ResetChangesQueued(); break;
        case 37: { QDBusPendingReply<> _r = _t->Save();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->SaveQueued(); break;
        case 39: { QDBusPendingReply<> _r = _t->SetAndSaveBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->SetAndSaveBrightnessQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 41: { QDBusPendingReply<> _r = _t->SetBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->SetBrightnessQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 43: { QDBusPendingReply<> _r = _t->SetColorTemperature((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->SetColorTemperatureQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: { QDBusPendingReply<> _r = _t->SetMethodAdjustCCT((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 46: _t->SetMethodAdjustCCTQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: { QDBusPendingReply<> _r = _t->SetPrimary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->SetPrimaryQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: { QDBusPendingReply<> _r = _t->SwitchMode((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->SwitchModeQueued((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 51: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 52: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 53: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(BrightnessMap ) const>(_a, &__OrgDeepinDdeDisplay1Interface::BrightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(int ) const>(_a, &__OrgDeepinDdeDisplay1Interface::ColorTemperatureManualChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(int ) const>(_a, &__OrgDeepinDdeDisplay1Interface::ColorTemperatureModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeDisplay1Interface::CurrentCustomIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(const QStringList & ) const>(_a, &__OrgDeepinDdeDisplay1Interface::CustomIdListChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(uchar ) const>(_a, &__OrgDeepinDdeDisplay1Interface::DisplayModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeDisplay1Interface::HasChangedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(uint ) const>(_a, &__OrgDeepinDdeDisplay1Interface::MaxBacklightBrightnessChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(const QList<QDBusObjectPath> & ) const>(_a, &__OrgDeepinDdeDisplay1Interface::MonitorsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeDisplay1Interface::PrimaryChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(ScreenRect ) const>(_a, &__OrgDeepinDdeDisplay1Interface::PrimaryRectChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(ushort ) const>(_a, &__OrgDeepinDdeDisplay1Interface::ScreenHeightChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(ushort ) const>(_a, &__OrgDeepinDdeDisplay1Interface::ScreenWidthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(TouchscreenMap ) const>(_a, &__OrgDeepinDdeDisplay1Interface::TouchMapChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(TouchscreenInfoList ) const>(_a, &__OrgDeepinDdeDisplay1Interface::TouchscreensChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeDisplay1Interface::*)(TouchscreenInfoList_V2 ) const>(_a, &__OrgDeepinDdeDisplay1Interface::TouchscreensV2Changed, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BrightnessMap*>(_v) = _t->brightness(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->colorTemperatureManual(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->colorTemperatureMode(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->currentCustomId(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->customIdList(); break;
        case 5: *reinterpret_cast<uchar*>(_v) = _t->displayMode(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasChanged(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->maxBacklightBrightness(); break;
        case 8: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->monitors(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->primary(); break;
        case 10: *reinterpret_cast<ScreenRect*>(_v) = _t->primaryRect(); break;
        case 11: *reinterpret_cast<ushort*>(_v) = _t->screenHeight(); break;
        case 12: *reinterpret_cast<ushort*>(_v) = _t->screenWidth(); break;
        case 13: *reinterpret_cast<TouchscreenMap*>(_v) = _t->touchMap(); break;
        case 14: *reinterpret_cast<TouchscreenInfoList*>(_v) = _t->touchscreens(); break;
        case 15: *reinterpret_cast<TouchscreenInfoList_V2*>(_v) = _t->touchscreensV2(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeDisplay1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeDisplay1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31__OrgDeepinDdeDisplay1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeDisplay1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 54;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeDisplay1Interface::BrightnessChanged(BrightnessMap _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdeDisplay1Interface::ColorTemperatureManualChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeDisplay1Interface::ColorTemperatureModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeDisplay1Interface::CurrentCustomIdChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeDisplay1Interface::CustomIdListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeDisplay1Interface::DisplayModeChanged(uchar _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeDisplay1Interface::HasChangedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdeDisplay1Interface::MaxBacklightBrightnessChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdeDisplay1Interface::MonitorsChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __OrgDeepinDdeDisplay1Interface::PrimaryChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __OrgDeepinDdeDisplay1Interface::PrimaryRectChanged(ScreenRect _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __OrgDeepinDdeDisplay1Interface::ScreenHeightChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __OrgDeepinDdeDisplay1Interface::ScreenWidthChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __OrgDeepinDdeDisplay1Interface::TouchMapChanged(TouchscreenMap _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __OrgDeepinDdeDisplay1Interface::TouchscreensChanged(TouchscreenInfoList _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __OrgDeepinDdeDisplay1Interface::TouchscreensV2Changed(TouchscreenInfoList_V2 _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeDisplay1Interface *>(this), &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
