/****************************************************************************
** Meta object code from reading C++ file 'traymanager1adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "traymanager1adaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traymanager1adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19TrayManager1AdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto TrayManager1Adaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19TrayManager1AdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrayManager1Adaptor",
        "D-Bus Interface",
        "org.deepin.dde.TrayManager1",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.dde.TrayManager1\">\n    <method na"
        "me=\"EnableNotification\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"win\"/>\n      <arg direction=\"in\" type=\"b\" name=\"ena"
        "bled\"/>\n    </method>\n    <method name=\"GetName\">\n      <arg"
        " direction=\"in\" type=\"u\" name=\"win\"/>\n      <arg direction="
        "\"out\" type=\"s\" name=\"name\"/>\n    </method>\n    <method nam"
        "e=\"Manage\">\n      <arg direction=\"out\" type=\"b\" name=\"ok\""
        "/>\n    </method>\n    <signal name=\"Inited\"/>\n    <signal name"
        "=\"Added\">\n      <arg type=\"u\" name=\"id\"/>\n    </signal>\n "
        "   <signal name=\"Removed\">\n      <arg type=\"u\" name=\"id\"/>\n"
        "    </signal>\n    <signal name=\"Changed\">\n      <arg type=\"u\""
        " name=\"id\"/>\n    </signal>\n    <property access=\"read\" type="
        "\"au\" name=\"TrayIcons\">\n      <annotation value=\"TrayList\" n"
        "ame=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </property>\n  </in"
        "terface>\n",
        "Added",
        "",
        "id",
        "Changed",
        "Inited",
        "Removed",
        "EnableNotification",
        "win",
        "enabled",
        "GetName",
        "Manage",
        "TrayIcons",
        "TrayList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Added'
        QtMocHelpers::SignalData<void(uint)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(uint)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Signal 'Inited'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Removed'
        QtMocHelpers::SignalData<void(uint)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Slot 'EnableNotification'
        QtMocHelpers::SlotData<void(uint, bool)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'GetName'
        QtMocHelpers::SlotData<QString(uint)>(14, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 12 },
        }}),
        // Slot 'Manage'
        QtMocHelpers::SlotData<bool()>(15, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'TrayIcons'
        QtMocHelpers::PropertyData<TrayList>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TrayManager1Adaptor, qt_meta_tag_ZN19TrayManager1AdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TrayManager1Adaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TrayManager1AdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TrayManager1AdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TrayManager1AdaptorE_t>.metaTypes,
    nullptr
} };

void TrayManager1Adaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrayManager1Adaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Added((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->Changed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->Inited(); break;
        case 3: _t->Removed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->EnableNotification((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: { QString _r = _t->GetName((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->Manage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrayManager1Adaptor::*)(uint )>(_a, &TrayManager1Adaptor::Added, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1Adaptor::*)(uint )>(_a, &TrayManager1Adaptor::Changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1Adaptor::*)()>(_a, &TrayManager1Adaptor::Inited, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1Adaptor::*)(uint )>(_a, &TrayManager1Adaptor::Removed, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TrayList*>(_v) = _t->trayIcons(); break;
        default: break;
        }
    }
}

const QMetaObject *TrayManager1Adaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrayManager1Adaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TrayManager1AdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int TrayManager1Adaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TrayManager1Adaptor::Added(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TrayManager1Adaptor::Changed(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TrayManager1Adaptor::Inited()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TrayManager1Adaptor::Removed(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
