/****************************************************************************
** Meta object code from reading C++ file 'power1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "power1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'power1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdePower1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdePower1Interface",
        "BatteryAdded",
        "",
        "QDBusObjectPath",
        "objpath",
        "BatteryDisplayUpdate",
        "timestamp",
        "BatteryRemoved",
        "LidClosed",
        "LidOpened",
        "BatteryPercentageChanged",
        "value",
        "BatteryStatusChanged",
        "BatteryTimeToEmptyChanged",
        "BatteryTimeToFullChanged",
        "HasBatteryChanged",
        "HasLidSwitchChanged",
        "IsHighPerformanceSupportedChanged",
        "ModeChanged",
        "OnBatteryChanged",
        "PowerSavingModeAutoChanged",
        "PowerSavingModeAutoWhenBatteryLowChanged",
        "PowerSavingModeBrightnessDropPercentChanged",
        "PowerSavingModeEnabledChanged",
        "PowerSystemAutoToSleepWhenFreeChanged",
        "GetBatteries",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "Refresh",
        "QDBusPendingReply<>",
        "RefreshQueued",
        "RefreshBatteries",
        "RefreshBatteriesQueued",
        "RefreshMains",
        "RefreshMainsQueued",
        "SetMode",
        "mode",
        "SetModeQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "BatteryPercentage",
        "BatteryStatus",
        "BatteryTimeToEmpty",
        "BatteryTimeToFull",
        "HasBattery",
        "HasLidSwitch",
        "IsHighPerformanceSupported",
        "Mode",
        "OnBattery",
        "PowerSavingModeAuto",
        "PowerSavingModeAutoWhenBatteryLow",
        "PowerSavingModeBrightnessDropPercent",
        "PowerSavingModeEnabled",
        "PowerSystemAutoToSleepWhenFree"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BatteryAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'BatteryDisplayUpdate'
        QtMocHelpers::SignalData<void(qlonglong)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 },
        }}),
        // Signal 'BatteryRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'LidClosed'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LidOpened'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BatteryPercentageChanged'
        QtMocHelpers::SignalData<void(double) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 },
        }}),
        // Signal 'BatteryStatusChanged'
        QtMocHelpers::SignalData<void(uint) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'BatteryTimeToEmptyChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 11 },
        }}),
        // Signal 'BatteryTimeToFullChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 11 },
        }}),
        // Signal 'HasBatteryChanged'
        QtMocHelpers::SignalData<void(bool) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'HasLidSwitchChanged'
        QtMocHelpers::SignalData<void(bool) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'IsHighPerformanceSupportedChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'ModeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'OnBatteryChanged'
        QtMocHelpers::SignalData<void(bool) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'PowerSavingModeAutoChanged'
        QtMocHelpers::SignalData<void(bool) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'PowerSavingModeAutoWhenBatteryLowChanged'
        QtMocHelpers::SignalData<void(bool) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'PowerSavingModeBrightnessDropPercentChanged'
        QtMocHelpers::SignalData<void(uint) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'PowerSavingModeEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'PowerSystemAutoToSleepWhenFreeChanged'
        QtMocHelpers::SignalData<void(bool) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'GetBatteries'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(25, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'Refresh'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(27, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'RefreshQueued'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RefreshBatteries'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(30, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'RefreshBatteriesQueued'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RefreshMains'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(32, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'RefreshMainsQueued'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(34, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'SetModeQueued'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 45 }, { 0x80000000 | 46, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'BatteryPercentage'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags, 5),
        // property 'BatteryStatus'
        QtMocHelpers::PropertyData<uint>(48, QMetaType::UInt, QMC::DefaultPropertyFlags, 6),
        // property 'BatteryTimeToEmpty'
        QtMocHelpers::PropertyData<qulonglong>(49, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 7),
        // property 'BatteryTimeToFull'
        QtMocHelpers::PropertyData<qulonglong>(50, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 8),
        // property 'HasBattery'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'HasLidSwitch'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'IsHighPerformanceSupported'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'Mode'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'OnBattery'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'PowerSavingModeAuto'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'PowerSavingModeAutoWhenBatteryLow'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'PowerSavingModeBrightnessDropPercent'
        QtMocHelpers::PropertyData<uint>(58, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'PowerSavingModeEnabled'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'PowerSystemAutoToSleepWhenFree'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdePower1Interface, qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdePower1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdePower1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdePower1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BatteryAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 1: _t->BatteryDisplayUpdate((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 2: _t->BatteryRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 3: _t->LidClosed(); break;
        case 4: _t->LidOpened(); break;
        case 5: _t->BatteryPercentageChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->BatteryStatusChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->BatteryTimeToEmptyChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 8: _t->BatteryTimeToFullChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 9: _t->HasBatteryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->HasLidSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->IsHighPerformanceSupportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->ModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->OnBatteryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->PowerSavingModeAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->PowerSavingModeAutoWhenBatteryLowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->PowerSavingModeBrightnessDropPercentChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 17: _t->PowerSavingModeEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->PowerSystemAutoToSleepWhenFreeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetBatteries();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->Refresh();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->RefreshQueued(); break;
        case 22: { QDBusPendingReply<> _r = _t->RefreshBatteries();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->RefreshBatteriesQueued(); break;
        case 24: { QDBusPendingReply<> _r = _t->RefreshMains();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->RefreshMainsQueued(); break;
        case 26: { QDBusPendingReply<> _r = _t->SetMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->SetModeQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 29: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 30: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdePower1Interface::BatteryAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(qlonglong )>(_a, &__OrgDeepinDdePower1Interface::BatteryDisplayUpdate, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(const QDBusObjectPath & )>(_a, &__OrgDeepinDdePower1Interface::BatteryRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)()>(_a, &__OrgDeepinDdePower1Interface::LidClosed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)()>(_a, &__OrgDeepinDdePower1Interface::LidOpened, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(double ) const>(_a, &__OrgDeepinDdePower1Interface::BatteryPercentageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(uint ) const>(_a, &__OrgDeepinDdePower1Interface::BatteryStatusChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(qulonglong ) const>(_a, &__OrgDeepinDdePower1Interface::BatteryTimeToEmptyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(qulonglong ) const>(_a, &__OrgDeepinDdePower1Interface::BatteryTimeToFullChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::HasBatteryChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::HasLidSwitchChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::IsHighPerformanceSupportedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdePower1Interface::ModeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::OnBatteryChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::PowerSavingModeAutoChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::PowerSavingModeAutoWhenBatteryLowChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(uint ) const>(_a, &__OrgDeepinDdePower1Interface::PowerSavingModeBrightnessDropPercentChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::PowerSavingModeEnabledChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdePower1Interface::*)(bool ) const>(_a, &__OrgDeepinDdePower1Interface::PowerSystemAutoToSleepWhenFreeChanged, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->batteryPercentage(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->batteryStatus(); break;
        case 2: *reinterpret_cast<qulonglong*>(_v) = _t->batteryTimeToEmpty(); break;
        case 3: *reinterpret_cast<qulonglong*>(_v) = _t->batteryTimeToFull(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasBattery(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasLidSwitch(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isHighPerformanceSupported(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->mode(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->onBattery(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeAuto(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeAutoWhenBatteryLow(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->powerSavingModeBrightnessDropPercent(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeEnabled(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->powerSystemAutoToSleepWhenFree(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 9: _t->setPowerSavingModeAuto(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setPowerSavingModeAutoWhenBatteryLow(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setPowerSavingModeBrightnessDropPercent(*reinterpret_cast<uint*>(_v)); break;
        case 12: _t->setPowerSavingModeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setPowerSystemAutoToSleepWhenFree(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdePower1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdePower1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29__OrgDeepinDdePower1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdePower1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdePower1Interface::BatteryAdded(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdePower1Interface::BatteryDisplayUpdate(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdePower1Interface::BatteryRemoved(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdePower1Interface::LidClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void __OrgDeepinDdePower1Interface::LidOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void __OrgDeepinDdePower1Interface::BatteryPercentageChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdePower1Interface::BatteryStatusChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdePower1Interface::BatteryTimeToEmptyChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdePower1Interface::BatteryTimeToFullChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __OrgDeepinDdePower1Interface::HasBatteryChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __OrgDeepinDdePower1Interface::HasLidSwitchChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __OrgDeepinDdePower1Interface::IsHighPerformanceSupportedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __OrgDeepinDdePower1Interface::ModeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __OrgDeepinDdePower1Interface::OnBatteryChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __OrgDeepinDdePower1Interface::PowerSavingModeAutoChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __OrgDeepinDdePower1Interface::PowerSavingModeAutoWhenBatteryLowChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __OrgDeepinDdePower1Interface::PowerSavingModeBrightnessDropPercentChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __OrgDeepinDdePower1Interface::PowerSavingModeEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void __OrgDeepinDdePower1Interface::PowerSystemAutoToSleepWhenFreeChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdePower1Interface *>(this), &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
