/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.TrayManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef TRAYMANAGER1INTERFACE_H
#define TRAYMANAGER1INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "api/types/traylist.h"

/*
 * Proxy class for interface org.deepin.dde.TrayManager1
 */
class TrayManager: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.TrayManager1"; }

public:
    TrayManager(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~TrayManager();

    Q_PROPERTY(TrayList TrayIcons READ trayIcons)
    inline TrayList trayIcons() const
    { return qvariant_cast< TrayList >(property("TrayIcons")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> EnableNotification(uint win, bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(win) << QVariant::fromValue(enabled);
        return asyncCallWithArgumentList(QStringLiteral("EnableNotification"), argumentList);
    }

    inline QDBusPendingReply<QString> GetName(uint win)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(win);
        return asyncCallWithArgumentList(QStringLiteral("GetName"), argumentList);
    }

    inline QDBusPendingReply<bool> Manage()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Manage"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Added(uint id);
    void Changed(uint id);
    void Inited();
    void Removed(uint id);
};

namespace org {
  namespace deepin {
    namespace dde {
      using TrayManager1 = ::TrayManager;
    }
  }
}

#endif
