/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -p timedate1interface /build/deepin-tray-loader/src/dde-tray-loader/plugins/dde-dock/dbus/xml/org.deepin.dde.Timedate1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef TIMEDATE1INTERFACE_H
#define TIMEDATE1INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>

#include "types/zoneinfo.h"

/*
 * Proxy class for interface org.deepin.dde.Timedate1
 */
class __OrgDeepinDdeTimedate1InterfacePrivate;
class __OrgDeepinDdeTimedate1Interface : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Timedate1"; }

public:
    explicit __OrgDeepinDdeTimedate1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__OrgDeepinDdeTimedate1Interface();

    Q_PROPERTY(bool CanNTP READ canNTP NOTIFY CanNTPChanged)
    bool canNTP();

    Q_PROPERTY(int DSTOffset READ dSTOffset WRITE setDSTOffset NOTIFY DSTOffsetChanged)
    int dSTOffset();
    void setDSTOffset(int value);

    Q_PROPERTY(bool LocalRTC READ localRTC NOTIFY LocalRTCChanged)
    bool localRTC();

    Q_PROPERTY(int LongDateFormat READ longDateFormat WRITE setLongDateFormat NOTIFY LongDateFormatChanged)
    int longDateFormat();
    void setLongDateFormat(int value);

    Q_PROPERTY(int LongTimeFormat READ longTimeFormat WRITE setLongTimeFormat NOTIFY LongTimeFormatChanged)
    int longTimeFormat();
    void setLongTimeFormat(int value);

    Q_PROPERTY(bool NTP READ nTP NOTIFY NTPChanged)
    bool nTP();

    Q_PROPERTY(QString NTPServer READ nTPServer NOTIFY NTPServerChanged)
    QString nTPServer();

    Q_PROPERTY(int ShortDateFormat READ shortDateFormat WRITE setShortDateFormat NOTIFY ShortDateFormatChanged)
    int shortDateFormat();
    void setShortDateFormat(int value);

    Q_PROPERTY(int ShortTimeFormat READ shortTimeFormat WRITE setShortTimeFormat NOTIFY ShortTimeFormatChanged)
    int shortTimeFormat();
    void setShortTimeFormat(int value);

    Q_PROPERTY(QString Timezone READ timezone NOTIFY TimezoneChanged)
    QString timezone();

    Q_PROPERTY(bool Use24HourFormat READ use24HourFormat WRITE setUse24HourFormat NOTIFY Use24HourFormatChanged)
    bool use24HourFormat();
    void setUse24HourFormat(bool value);

    Q_PROPERTY(QStringList UserTimezones READ userTimezones NOTIFY UserTimezonesChanged)
    QStringList userTimezones();

    Q_PROPERTY(int WeekBegins READ weekBegins WRITE setWeekBegins NOTIFY WeekBeginsChanged)
    int weekBegins();
    void setWeekBegins(int value);

    Q_PROPERTY(int WeekdayFormat READ weekdayFormat WRITE setWeekdayFormat NOTIFY WeekdayFormatChanged)
    int weekdayFormat();
    void setWeekdayFormat(int value);

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> AddUserTimezone(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("AddUserTimezone"), argumentList);
    }

    inline void AddUserTimezoneQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("AddUserTimezone"), argumentList);
    }


    inline QDBusPendingReply<> DeleteUserTimezone(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("DeleteUserTimezone"), argumentList);
    }

    inline void DeleteUserTimezoneQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("DeleteUserTimezone"), argumentList);
    }


    inline QDBusPendingReply<QStringList> GetSampleNTPServers()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetSampleNTPServers"), argumentList);
    }



    inline QDBusPendingReply<ZoneInfo> GetZoneInfo(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetZoneInfo"), argumentList);
    }



    inline QDBusPendingReply<QStringList> GetZoneList()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetZoneList"), argumentList);
    }



    inline QDBusPendingReply<> SetDate(int in0, int in1, int in2, int in3, int in4, int in5, int in6)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2) << QVariant::fromValue(in3) << QVariant::fromValue(in4) << QVariant::fromValue(in5) << QVariant::fromValue(in6);
        return asyncCallWithArgumentList(QStringLiteral("SetDate"), argumentList);
    }

    inline void SetDateQueued(int in0, int in1, int in2, int in3, int in4, int in5, int in6)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2) << QVariant::fromValue(in3) << QVariant::fromValue(in4) << QVariant::fromValue(in5) << QVariant::fromValue(in6);

        CallQueued(QStringLiteral("SetDate"), argumentList);
    }


    inline QDBusPendingReply<> SetLocalRTC(bool in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetLocalRTC"), argumentList);
    }

    inline void SetLocalRTCQueued(bool in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetLocalRTC"), argumentList);
    }


    inline QDBusPendingReply<> SetNTP(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetNTP"), argumentList);
    }

    inline void SetNTPQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetNTP"), argumentList);
    }


    inline QDBusPendingReply<> SetNTPServer(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetNTPServer"), argumentList);
    }

    inline void SetNTPServerQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetNTPServer"), argumentList);
    }


    inline QDBusPendingReply<> SetTime(qlonglong in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetTime"), argumentList);
    }

    inline void SetTimeQueued(qlonglong in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetTime"), argumentList);
    }


    inline QDBusPendingReply<> SetTimezone(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetTimezone"), argumentList);
    }

    inline void SetTimezoneQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetTimezone"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void TimeUpdate();
    // begin property changed signals
    void CanNTPChanged(bool  value) const;
    void DSTOffsetChanged(int  value) const;
    void LocalRTCChanged(bool  value) const;
    void LongDateFormatChanged(int  value) const;
    void LongTimeFormatChanged(int  value) const;
    void NTPChanged(bool  value) const;
    void NTPServerChanged(const QString & value) const;
    void ShortDateFormatChanged(int  value) const;
    void ShortTimeFormatChanged(int  value) const;
    void TimezoneChanged(const QString & value) const;
    void Use24HourFormatChanged(bool  value) const;
    void UserTimezonesChanged(const QStringList & value) const;
    void WeekBeginsChanged(int  value) const;
    void WeekdayFormatChanged(int  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __OrgDeepinDdeTimedate1InterfacePrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__OrgDeepinDdeTimedate1Interface Timedate1;
    }
  }
}
#endif
