/****************************************************************************
** Meta object code from reading C++ file 'mediamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plugins/dde-dock/media/mediamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MediaModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaModel::qt_create_metaobjectdata<qt_meta_tag_ZN10MediaModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaModel",
        "mediaAcquired",
        "",
        "mediaChanged",
        "mediaLosted",
        "controlStateChanged",
        "state",
        "playStateChanged",
        "mediaPathChanged",
        "path",
        "mediaInfoChanged",
        "MediaInfo",
        "info",
        "onCanControlChanged",
        "canControl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mediaAcquired'
        QtMocHelpers::SignalData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaChanged'
        QtMocHelpers::SignalData<void() const>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaLosted'
        QtMocHelpers::SignalData<void() const>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlStateChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'playStateChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'mediaPathChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'mediaInfoChanged'
        QtMocHelpers::SignalData<void(const MediaInfo &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onCanControlChanged'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MediaModel, qt_meta_tag_ZN10MediaModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MediaModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MediaModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MediaModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MediaModelE_t>.metaTypes,
    nullptr
} };

void MediaModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mediaAcquired(); break;
        case 1: _t->mediaChanged(); break;
        case 2: _t->mediaLosted(); break;
        case 3: _t->controlStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->playStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->mediaPathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->mediaInfoChanged((*reinterpret_cast<std::add_pointer_t<MediaInfo>>(_a[1]))); break;
        case 7: _t->onCanControlChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)() const>(_a, &MediaModel::mediaAcquired, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)() const>(_a, &MediaModel::mediaChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)() const>(_a, &MediaModel::mediaLosted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)(bool )>(_a, &MediaModel::controlStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)(bool )>(_a, &MediaModel::playStateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)(const QString & )>(_a, &MediaModel::mediaPathChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaModel::*)(const MediaInfo & )>(_a, &MediaModel::mediaInfoChanged, 6))
            return;
    }
}

const QMetaObject *MediaModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MediaModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DSingleton<MediaModel>"))
        return static_cast< Dtk::Core::DSingleton<MediaModel>*>(this);
    return QObject::qt_metacast(_clname);
}

int MediaModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void MediaModel::mediaAcquired()const
{
    QMetaObject::activate(const_cast< MediaModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MediaModel::mediaChanged()const
{
    QMetaObject::activate(const_cast< MediaModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MediaModel::mediaLosted()const
{
    QMetaObject::activate(const_cast< MediaModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MediaModel::controlStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MediaModel::playStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MediaModel::mediaPathChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MediaModel::mediaInfoChanged(const MediaInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
