/****************************************************************************
** Meta object code from reading C++ file 'audio1sinkinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "audio1sinkinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'audio1sinkinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeAudio1SinkInterface::qt_create_metaobjectdata<qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeAudio1SinkInterface",
        "ActivePortChanged",
        "",
        "AudioPort",
        "value",
        "BalanceChanged",
        "BaseVolumeChanged",
        "CardChanged",
        "DescriptionChanged",
        "FadeChanged",
        "MuteChanged",
        "NameChanged",
        "PortsChanged",
        "AudioPortList",
        "SupportBalanceChanged",
        "SupportFadeChanged",
        "VolumeChanged",
        "GetMeter",
        "QDBusPendingReply<QDBusObjectPath>",
        "SetBalance",
        "QDBusPendingReply<>",
        "in0",
        "in1",
        "SetBalanceQueued",
        "SetFade",
        "SetFadeQueued",
        "SetMute",
        "SetMuteQueued",
        "SetPort",
        "SetPortQueued",
        "SetVolume",
        "SetVolumeQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "ActivePort",
        "Balance",
        "BaseVolume",
        "Card",
        "Description",
        "Fade",
        "Mute",
        "Name",
        "Ports",
        "SupportBalance",
        "SupportFade",
        "Volume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActivePortChanged'
        QtMocHelpers::SignalData<void(AudioPort) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'BalanceChanged'
        QtMocHelpers::SignalData<void(double) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Signal 'BaseVolumeChanged'
        QtMocHelpers::SignalData<void(double) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Signal 'CardChanged'
        QtMocHelpers::SignalData<void(uint) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Signal 'DescriptionChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'FadeChanged'
        QtMocHelpers::SignalData<void(double) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Signal 'MuteChanged'
        QtMocHelpers::SignalData<void(bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'PortsChanged'
        QtMocHelpers::SignalData<void(AudioPortList) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 4 },
        }}),
        // Signal 'SupportBalanceChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'SupportFadeChanged'
        QtMocHelpers::SignalData<void(bool) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'VolumeChanged'
        QtMocHelpers::SignalData<void(double) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'GetMeter'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'SetBalance'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double, bool)>(19, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Double, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'SetBalanceQueued'
        QtMocHelpers::SlotData<void(double, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'SetFade'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double)>(24, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Double, 21 },
        }}),
        // Slot 'SetFadeQueued'
        QtMocHelpers::SlotData<void(double)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 21 },
        }}),
        // Slot 'SetMute'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(26, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'SetMuteQueued'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'SetPort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'SetPortQueued'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'SetVolume'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double, bool)>(30, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Double, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'SetVolumeQueued'
        QtMocHelpers::SlotData<void(double, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 40 }, { 0x80000000 | 41, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ActivePort'
        QtMocHelpers::PropertyData<AudioPort>(42, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'Balance'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags, 1),
        // property 'BaseVolume'
        QtMocHelpers::PropertyData<double>(44, QMetaType::Double, QMC::DefaultPropertyFlags, 2),
        // property 'Card'
        QtMocHelpers::PropertyData<uint>(45, QMetaType::UInt, QMC::DefaultPropertyFlags, 3),
        // property 'Description'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'Fade'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags, 5),
        // property 'Mute'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'Ports'
        QtMocHelpers::PropertyData<AudioPortList>(50, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'SupportBalance'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'SupportFade'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'Volume'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeAudio1SinkInterface, qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeAudio1SinkInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeAudio1SinkInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeAudio1SinkInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActivePortChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 1: _t->BalanceChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->BaseVolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->CardChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->DescriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->FadeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->MuteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->PortsChanged((*reinterpret_cast<std::add_pointer_t<AudioPortList>>(_a[1]))); break;
        case 9: _t->SupportBalanceChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->SupportFadeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->VolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 12: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetMeter();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->SetBalance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->SetBalanceQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: { QDBusPendingReply<> _r = _t->SetFade((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->SetFadeQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: { QDBusPendingReply<> _r = _t->SetMute((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->SetMuteQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: { QDBusPendingReply<> _r = _t->SetPort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->SetPortQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: { QDBusPendingReply<> _r = _t->SetVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->SetVolumeQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 23: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 24: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 25: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(AudioPort ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::ActivePortChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(double ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::BalanceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(double ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::BaseVolumeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(uint ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::CardChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::DescriptionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(double ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::FadeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(bool ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::MuteChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::NameChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(AudioPortList ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::PortsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(bool ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::SupportBalanceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(bool ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::SupportFadeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAudio1SinkInterface::*)(double ) const>(_a, &__OrgDeepinDdeAudio1SinkInterface::VolumeChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AudioPort*>(_v) = _t->activePort(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->balance(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->baseVolume(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->card(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->fade(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->mute(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 8: *reinterpret_cast<AudioPortList*>(_v) = _t->ports(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->supportBalance(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->supportFade(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeAudio1SinkInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeAudio1SinkInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33__OrgDeepinDdeAudio1SinkInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeAudio1SinkInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeAudio1SinkInterface::ActivePortChanged(AudioPort _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdeAudio1SinkInterface::BalanceChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeAudio1SinkInterface::BaseVolumeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeAudio1SinkInterface::CardChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeAudio1SinkInterface::DescriptionChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeAudio1SinkInterface::FadeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeAudio1SinkInterface::MuteChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdeAudio1SinkInterface::NameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdeAudio1SinkInterface::PortsChanged(AudioPortList _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __OrgDeepinDdeAudio1SinkInterface::SupportBalanceChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __OrgDeepinDdeAudio1SinkInterface::SupportFadeChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __OrgDeepinDdeAudio1SinkInterface::VolumeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAudio1SinkInterface *>(this), &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
