// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_dockdbusproxy.cpp"
#include "EWIEGA46WW/moc_pluginitem.cpp"
#include "EWIEGA46WW/moc_pluginmanager.cpp"
#include "EWIEGA46WW/moc_quickpluginitem.cpp"
#include "EWIEGA46WW/moc_widgetplugin.cpp"
