/****************************************************************************
** Meta object code from reading C++ file 'traymanager1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plugins/application-tray/traymanager1.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traymanager1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12TrayManager1E_t {};
} // unnamed namespace

template <> constexpr inline auto TrayManager1::qt_create_metaobjectdata<qt_meta_tag_ZN12TrayManager1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrayManager1",
        "D-Bus Interface",
        "org.deepin.dde.TrayManager1",
        "Added",
        "",
        "uint32_t",
        "id",
        "Removed",
        "Changed",
        "Inited",
        "reclainRequested",
        "Manage",
        "GetName",
        "win",
        "EnableNotification",
        "enabled",
        "TrayIcons",
        "TrayList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Added'
        QtMocHelpers::SignalData<void(uint32_t)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'Removed'
        QtMocHelpers::SignalData<void(uint32_t)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(uint32_t)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'Inited'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reclainRequested'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Manage'
        QtMocHelpers::SlotData<bool()>(11, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetName'
        QtMocHelpers::SlotData<QString(uint32_t)>(12, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'EnableNotification'
        QtMocHelpers::SlotData<void(uint32_t, bool)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 13 }, { QMetaType::Bool, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'TrayIcons'
        QtMocHelpers::PropertyData<TrayList>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TrayManager1, qt_meta_tag_ZN12TrayManager1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TrayManager1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TrayManager1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TrayManager1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12TrayManager1E_t>.metaTypes,
    nullptr
} };

void TrayManager1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrayManager1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Added((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 1: _t->Removed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 2: _t->Changed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 3: _t->Inited(); break;
        case 4: _t->reclainRequested(); break;
        case 5: { bool _r = _t->Manage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->GetName((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->EnableNotification((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrayManager1::*)(uint32_t )>(_a, &TrayManager1::Added, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1::*)(uint32_t )>(_a, &TrayManager1::Removed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1::*)(uint32_t )>(_a, &TrayManager1::Changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1::*)()>(_a, &TrayManager1::Inited, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayManager1::*)()>(_a, &TrayManager1::reclainRequested, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TrayList*>(_v) = _t->trayIcons(); break;
        default: break;
        }
    }
}

const QMetaObject *TrayManager1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrayManager1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TrayManager1E_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int TrayManager1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TrayManager1::Added(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TrayManager1::Removed(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TrayManager1::Changed(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TrayManager1::Inited()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TrayManager1::reclainRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
