/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -p bluetooth1interface /build/deepin-tray-loader/src/dde-tray-loader/plugins/dde-dock/dbus/xml/org.deepin.dde.Bluetooth1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BLUETOOTH1INTERFACE_H
#define BLUETOOTH1INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.deepin.dde.Bluetooth1
 */
class __OrgDeepinDdeBluetooth1InterfacePrivate;
class __OrgDeepinDdeBluetooth1Interface : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Bluetooth1"; }

public:
    explicit __OrgDeepinDdeBluetooth1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__OrgDeepinDdeBluetooth1Interface();

    Q_PROPERTY(bool CanSendFile READ canSendFile NOTIFY CanSendFileChanged)
    bool canSendFile();

    Q_PROPERTY(bool DisplaySwitch READ displaySwitch WRITE setDisplaySwitch NOTIFY DisplaySwitchChanged)
    bool displaySwitch();
    void setDisplaySwitch(bool value);

    Q_PROPERTY(uint State READ state NOTIFY StateChanged)
    uint state();

    Q_PROPERTY(bool Transportable READ transportable NOTIFY TransportableChanged)
    bool transportable();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> CancelTransferSession(const QDBusObjectPath &sessionPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(sessionPath);
        return asyncCallWithArgumentList(QStringLiteral("CancelTransferSession"), argumentList);
    }

    inline void CancelTransferSessionQueued(const QDBusObjectPath &sessionPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(sessionPath);

        CallQueued(QStringLiteral("CancelTransferSession"), argumentList);
    }


    inline QDBusPendingReply<> ClearUnpairedDevice()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ClearUnpairedDevice"), argumentList);
    }

    inline void ClearUnpairedDeviceQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("ClearUnpairedDevice"), argumentList);
    }


    inline QDBusPendingReply<> Confirm(const QDBusObjectPath &device, bool accept)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(accept);
        return asyncCallWithArgumentList(QStringLiteral("Confirm"), argumentList);
    }

    inline void ConfirmQueued(const QDBusObjectPath &device, bool accept)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(accept);

        CallQueued(QStringLiteral("Confirm"), argumentList);
    }


    inline QDBusPendingReply<> ConnectDevice(const QDBusObjectPath &device, const QDBusObjectPath &adapter)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(adapter);
        return asyncCallWithArgumentList(QStringLiteral("ConnectDevice"), argumentList);
    }

    inline void ConnectDeviceQueued(const QDBusObjectPath &device, const QDBusObjectPath &adapter)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(adapter);

        CallQueued(QStringLiteral("ConnectDevice"), argumentList);
    }


    inline QDBusPendingReply<QString> DebugInfo()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("DebugInfo"), argumentList);
    }



    inline QDBusPendingReply<> DisconnectDevice(const QDBusObjectPath &device)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device);
        return asyncCallWithArgumentList(QStringLiteral("DisconnectDevice"), argumentList);
    }

    inline void DisconnectDeviceQueued(const QDBusObjectPath &device)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device);

        CallQueued(QStringLiteral("DisconnectDevice"), argumentList);
    }


    inline QDBusPendingReply<> FeedPasskey(const QDBusObjectPath &device, bool accept, uint passkey)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(accept) << QVariant::fromValue(passkey);
        return asyncCallWithArgumentList(QStringLiteral("FeedPasskey"), argumentList);
    }

    inline void FeedPasskeyQueued(const QDBusObjectPath &device, bool accept, uint passkey)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(accept) << QVariant::fromValue(passkey);

        CallQueued(QStringLiteral("FeedPasskey"), argumentList);
    }


    inline QDBusPendingReply<> FeedPinCode(const QDBusObjectPath &device, bool accept, const QString &pinCode)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(accept) << QVariant::fromValue(pinCode);
        return asyncCallWithArgumentList(QStringLiteral("FeedPinCode"), argumentList);
    }

    inline void FeedPinCodeQueued(const QDBusObjectPath &device, bool accept, const QString &pinCode)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(accept) << QVariant::fromValue(pinCode);

        CallQueued(QStringLiteral("FeedPinCode"), argumentList);
    }


    inline QDBusPendingReply<QString> GetAdapters()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetAdapters"), argumentList);
    }



    inline QDBusPendingReply<QString> GetDevices(const QDBusObjectPath &adapter)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter);
        return asyncCallWithArgumentList(QStringLiteral("GetDevices"), argumentList);
    }



    inline QDBusPendingReply<> RemoveDevice(const QDBusObjectPath &adapter, const QDBusObjectPath &device)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(device);
        return asyncCallWithArgumentList(QStringLiteral("RemoveDevice"), argumentList);
    }

    inline void RemoveDeviceQueued(const QDBusObjectPath &adapter, const QDBusObjectPath &device)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(device);

        CallQueued(QStringLiteral("RemoveDevice"), argumentList);
    }


    inline QDBusPendingReply<> RequestDiscovery(const QDBusObjectPath &adapter)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter);
        return asyncCallWithArgumentList(QStringLiteral("RequestDiscovery"), argumentList);
    }

    inline void RequestDiscoveryQueued(const QDBusObjectPath &adapter)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter);

        CallQueued(QStringLiteral("RequestDiscovery"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> SendFiles(const QString &device, const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("SendFiles"), argumentList);
    }



    inline QDBusPendingReply<> SetAdapterAlias(const QDBusObjectPath &adapter, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(alias);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterAlias"), argumentList);
    }

    inline void SetAdapterAliasQueued(const QDBusObjectPath &adapter, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(alias);

        CallQueued(QStringLiteral("SetAdapterAlias"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterDiscoverable(const QDBusObjectPath &adapter, bool discoverable)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(discoverable);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterDiscoverable"), argumentList);
    }

    inline void SetAdapterDiscoverableQueued(const QDBusObjectPath &adapter, bool discoverable)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(discoverable);

        CallQueued(QStringLiteral("SetAdapterDiscoverable"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterDiscoverableTimeout(const QDBusObjectPath &adapter, uint timeout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(timeout);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterDiscoverableTimeout"), argumentList);
    }

    inline void SetAdapterDiscoverableTimeoutQueued(const QDBusObjectPath &adapter, uint timeout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(timeout);

        CallQueued(QStringLiteral("SetAdapterDiscoverableTimeout"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterDiscovering(const QDBusObjectPath &adapter, bool discovering)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(discovering);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterDiscovering"), argumentList);
    }

    inline void SetAdapterDiscoveringQueued(const QDBusObjectPath &adapter, bool discovering)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(discovering);

        CallQueued(QStringLiteral("SetAdapterDiscovering"), argumentList);
    }


    inline QDBusPendingReply<> SetAdapterPowered(const QDBusObjectPath &adapter, bool powered)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(powered);
        return asyncCallWithArgumentList(QStringLiteral("SetAdapterPowered"), argumentList);
    }

    inline void SetAdapterPoweredQueued(const QDBusObjectPath &adapter, bool powered)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(adapter) << QVariant::fromValue(powered);

        CallQueued(QStringLiteral("SetAdapterPowered"), argumentList);
    }


    inline QDBusPendingReply<> SetDeviceAlias(const QDBusObjectPath &device, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(alias);
        return asyncCallWithArgumentList(QStringLiteral("SetDeviceAlias"), argumentList);
    }

    inline void SetDeviceAliasQueued(const QDBusObjectPath &device, const QString &alias)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(alias);

        CallQueued(QStringLiteral("SetDeviceAlias"), argumentList);
    }


    inline QDBusPendingReply<> SetDeviceTrusted(const QDBusObjectPath &device, bool trusted)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(trusted);
        return asyncCallWithArgumentList(QStringLiteral("SetDeviceTrusted"), argumentList);
    }

    inline void SetDeviceTrustedQueued(const QDBusObjectPath &device, bool trusted)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device) << QVariant::fromValue(trusted);

        CallQueued(QStringLiteral("SetDeviceTrusted"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void AdapterAdded(const QString &adapterJSON);
    void AdapterPropertiesChanged(const QString &adapterJSON);
    void AdapterRemoved(const QString &adapterJSON);
    void Cancelled(const QDBusObjectPath &device);
    void ConnectFailed(const QDBusObjectPath &device);
    void DeviceAdded(const QString &devJSON);
    void DevicePropertiesChanged(const QString &devJSON);
    void DeviceRemoved(const QString &devJSON);
    void DisplayPasskey(const QDBusObjectPath &device, uint passkey, uint entered);
    void DisplayPinCode(const QDBusObjectPath &device, const QString &pinCode);
    void ObexSessionCreated(const QDBusObjectPath &sessionPath);
    void ObexSessionProgress(const QDBusObjectPath &sessionPath, qulonglong totalSize, qulonglong transferred, int currentIdx);
    void ObexSessionRemoved(const QDBusObjectPath &sessionPath);
    void RequestAuthorization(const QDBusObjectPath &device);
    void RequestConfirmation(const QDBusObjectPath &device, const QString &passkey);
    void RequestPasskey(const QDBusObjectPath &device);
    void RequestPinCode(const QDBusObjectPath &device);
    void TransferCreated(const QString &file, const QDBusObjectPath &transferPath, const QDBusObjectPath &sessionPath);
    void TransferFailed(const QString &file, const QDBusObjectPath &sessionPath, const QString &errInfo);
    void TransferRemoved(const QString &file, const QDBusObjectPath &transferPath, const QDBusObjectPath &sessionPath, bool done);
    // begin property changed signals
    void CanSendFileChanged(bool  value) const;
    void DisplaySwitchChanged(bool  value) const;
    void StateChanged(uint  value) const;
    void TransportableChanged(bool  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __OrgDeepinDdeBluetooth1InterfacePrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__OrgDeepinDdeBluetooth1Interface Bluetooth1;
    }
  }
}
#endif
