/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.TrayManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "traymanager1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class TrayManager1Adaptor
 */

TrayManager1Adaptor::TrayManager1Adaptor(TrayManager1 *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

TrayManager1Adaptor::~TrayManager1Adaptor()
{
    // destructor
}

TrayList TrayManager1Adaptor::trayIcons() const
{
    // get the value of property TrayIcons
    return qvariant_cast< TrayList >(parent()->property("TrayIcons"));
}

void TrayManager1Adaptor::EnableNotification(uint win, bool enabled)
{
    // handle method call org.deepin.dde.TrayManager1.EnableNotification
    parent()->EnableNotification(win, enabled);
}

QString TrayManager1Adaptor::GetName(uint win)
{
    // handle method call org.deepin.dde.TrayManager1.GetName
    return parent()->GetName(win);
}

bool TrayManager1Adaptor::Manage()
{
    // handle method call org.deepin.dde.TrayManager1.Manage
    return parent()->Manage();
}


#include "moc_traymanager1adaptor.cpp"
