/****************************************************************************
** Meta object code from reading C++ file 'abstracttrayprotocol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plugins/application-tray/abstracttrayprotocol.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstracttrayprotocol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t {};
} // unnamed namespace

template <> constexpr inline auto tray::AbstractTrayProtocol::qt_create_metaobjectdata<qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tray::AbstractTrayProtocol",
        "trayCreated",
        "",
        "QPointer<AbstractTrayProtocolHandler>",
        "handler"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'trayCreated'
        QtMocHelpers::SignalData<void(QPointer<AbstractTrayProtocolHandler>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractTrayProtocol, qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject tray::AbstractTrayProtocol::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t>.metaTypes,
    nullptr
} };

void tray::AbstractTrayProtocol::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractTrayProtocol *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->trayCreated((*reinterpret_cast<std::add_pointer_t<QPointer<AbstractTrayProtocolHandler>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QPointer<AbstractTrayProtocolHandler> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocol::*)(QPointer<AbstractTrayProtocolHandler> )>(_a, &AbstractTrayProtocol::trayCreated, 0))
            return;
    }
}

const QMetaObject *tray::AbstractTrayProtocol::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tray::AbstractTrayProtocol::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray20AbstractTrayProtocolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int tray::AbstractTrayProtocol::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void tray::AbstractTrayProtocol::trayCreated(QPointer<AbstractTrayProtocolHandler> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto tray::AbstractTrayProtocolHandler::qt_create_metaobjectdata<qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tray::AbstractTrayProtocolHandler",
        "titleChanged",
        "",
        "statusChanged",
        "categoryChanged",
        "tooltiChanged",
        "iconChanged",
        "overlayIconChanged",
        "attentionIconChanged",
        "enabledChanged",
        "windowId",
        "uint32_t",
        "id",
        "title",
        "status",
        "category",
        "icon",
        "QIcon",
        "overlayIcon",
        "attentionIcon",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tooltiChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overlayIconChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attentionIconChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'windowId'
        QtMocHelpers::PropertyData<uint32_t>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'status'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'category'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'icon'
        QtMocHelpers::PropertyData<QIcon>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 4),
        // property 'overlayIcon'
        QtMocHelpers::PropertyData<QIcon>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 5),
        // property 'attentionIcon'
        QtMocHelpers::PropertyData<QIcon>(19, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 6),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractTrayProtocolHandler, qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject tray::AbstractTrayProtocolHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t>.metaTypes,
    nullptr
} };

void tray::AbstractTrayProtocolHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractTrayProtocolHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->statusChanged(); break;
        case 2: _t->categoryChanged(); break;
        case 3: _t->tooltiChanged(); break;
        case 4: _t->iconChanged(); break;
        case 5: _t->overlayIconChanged(); break;
        case 6: _t->attentionIconChanged(); break;
        case 7: _t->enabledChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::categoryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::tooltiChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::iconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::overlayIconChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::attentionIconChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractTrayProtocolHandler::*)()>(_a, &AbstractTrayProtocolHandler::enabledChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint32_t*>(_v) = _t->windowId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->category(); break;
        case 5: *reinterpret_cast<QIcon*>(_v) = _t->icon(); break;
        case 6: *reinterpret_cast<QIcon*>(_v) = _t->overlayIcon(); break;
        case 7: *reinterpret_cast<QIcon*>(_v) = _t->attentionIcon(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        default: break;
        }
    }
}

const QMetaObject *tray::AbstractTrayProtocolHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tray::AbstractTrayProtocolHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray27AbstractTrayProtocolHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int tray::AbstractTrayProtocolHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void tray::AbstractTrayProtocolHandler::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void tray::AbstractTrayProtocolHandler::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void tray::AbstractTrayProtocolHandler::categoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void tray::AbstractTrayProtocolHandler::tooltiChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void tray::AbstractTrayProtocolHandler::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void tray::AbstractTrayProtocolHandler::overlayIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void tray::AbstractTrayProtocolHandler::attentionIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void tray::AbstractTrayProtocolHandler::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
