/****************************************************************************
** Meta object code from reading C++ file 'appearance1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "appearance1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearance1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeAppearance1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeAppearance1Interface",
        "Changed",
        "",
        "in0",
        "in1",
        "Refreshed",
        "BackgroundChanged",
        "value",
        "CursorThemeChanged",
        "FontSizeChanged",
        "GlobalThemeChanged",
        "GtkThemeChanged",
        "IconThemeChanged",
        "MonospaceFontChanged",
        "OpacityChanged",
        "QtActiveColorChanged",
        "StandardFontChanged",
        "WallpaperSlideShowChanged",
        "Delete",
        "QDBusPendingReply<>",
        "DeleteQueued",
        "GetScaleFactor",
        "QDBusPendingReply<double>",
        "GetScreenScaleFactors",
        "QDBusPendingReply<QMap<QString,double>>",
        "List",
        "QDBusPendingReply<QString>",
        "Set",
        "SetQueued",
        "SetScaleFactor",
        "SetScaleFactorQueued",
        "SetScreenScaleFactors",
        "QMap<QString,double>",
        "scaleFactors",
        "SetScreenScaleFactorsQueued",
        "Show",
        "Thumbnail",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "Background",
        "CursorTheme",
        "FontSize",
        "GlobalTheme",
        "GtkTheme",
        "IconTheme",
        "MonospaceFont",
        "Opacity",
        "QtActiveColor",
        "StandardFont",
        "WallpaperSlideShow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'Refreshed'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'BackgroundChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'CursorThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'FontSizeChanged'
        QtMocHelpers::SignalData<void(double) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'GlobalThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'GtkThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'IconThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'MonospaceFontChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'OpacityChanged'
        QtMocHelpers::SignalData<void(double) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'QtActiveColorChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'StandardFontChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'WallpaperSlideShowChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'DeleteQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'GetScaleFactor'
        QtMocHelpers::SlotData<QDBusPendingReply<double>()>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'GetScreenScaleFactors'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,double> >()>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'List'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'Set'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'SetQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'SetScaleFactor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double)>(29, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Double, 3 },
        }}),
        // Slot 'SetScaleFactorQueued'
        QtMocHelpers::SlotData<void(double)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Slot 'SetScreenScaleFactors'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QMap<QString,double> &)>(31, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'SetScreenScaleFactorsQueued'
        QtMocHelpers::SlotData<void(const QMap<QString,double> &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QStringList &)>(35, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 }, { QMetaType::QStringList, 4 },
        }}),
        // Slot 'Thumbnail'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 45 }, { 0x80000000 | 46, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Background'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'CursorTheme'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'FontSize'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'GlobalTheme'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'GtkTheme'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'IconTheme'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'MonospaceFont'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'Opacity'
        QtMocHelpers::PropertyData<double>(54, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'QtActiveColor'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'StandardFont'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'WallpaperSlideShow'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeAppearance1Interface, qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeAppearance1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeAppearance1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeAppearance1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->Refreshed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->BackgroundChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->CursorThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->FontSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->GlobalThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->GtkThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->IconThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->MonospaceFontChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->OpacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->QtActiveColorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->StandardFontChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->WallpaperSlideShowChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->DeleteQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: { QDBusPendingReply<double> _r = _t->GetScaleFactor();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<double>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QMap<QString,double>> _r = _t->GetScreenScaleFactors();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,double>>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QString> _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->SetQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: { QDBusPendingReply<> _r = _t->SetScaleFactor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->SetScaleFactorQueued((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 22: { QDBusPendingReply<> _r = _t->SetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<QMap<QString,double>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->SetScreenScaleFactorsQueued((*reinterpret_cast<std::add_pointer_t<QMap<QString,double>>>(_a[1]))); break;
        case 24: { QDBusPendingReply<QString> _r = _t->Show((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<QString> _r = _t->Thumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 27: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 28: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & , const QString & )>(_a, &__OrgDeepinDdeAppearance1Interface::Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeAppearance1Interface::Refreshed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::BackgroundChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::CursorThemeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(double ) const>(_a, &__OrgDeepinDdeAppearance1Interface::FontSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::GlobalThemeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::GtkThemeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::IconThemeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::MonospaceFontChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(double ) const>(_a, &__OrgDeepinDdeAppearance1Interface::OpacityChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::QtActiveColorChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::StandardFontChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAppearance1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAppearance1Interface::WallpaperSlideShowChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->background(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->fontSize(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->globalTheme(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->gtkTheme(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->iconTheme(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->monospaceFont(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->qtActiveColor(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->standardFont(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->wallpaperSlideShow(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackground(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setCursorTheme(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFontSize(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setGtkTheme(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setIconTheme(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setMonospaceFont(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 8: _t->setQtActiveColor(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setStandardFont(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setWallpaperSlideShow(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeAppearance1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeAppearance1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34__OrgDeepinDdeAppearance1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeAppearance1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeAppearance1Interface::Changed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void __OrgDeepinDdeAppearance1Interface::Refreshed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeAppearance1Interface::BackgroundChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeAppearance1Interface::CursorThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeAppearance1Interface::FontSizeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __OrgDeepinDdeAppearance1Interface::GlobalThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __OrgDeepinDdeAppearance1Interface::GtkThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __OrgDeepinDdeAppearance1Interface::IconThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __OrgDeepinDdeAppearance1Interface::MonospaceFontChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __OrgDeepinDdeAppearance1Interface::OpacityChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __OrgDeepinDdeAppearance1Interface::QtActiveColorChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __OrgDeepinDdeAppearance1Interface::StandardFontChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __OrgDeepinDdeAppearance1Interface::WallpaperSlideShowChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAppearance1Interface *>(this), &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
