// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef COMMONDEF_H
#define COMMONDEF_H

#include <QString>

const QString CalendarServiceName = "com.deepin.dataserver.Calendar";
const QString CalendarPath = "/com/deepin/dataserver/Calendar";
const QString DateTimeServiceName = "org.deepin.dde.Timedate1";
const QString DateTimePath = "/org/deepin/dde/Timedate1";

#endif // COMMONDEF_H
