// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef BLUETOOTHCONSTANTS_H
#define BLUETOOTHCONSTANTS_H

const int DeviceItemHeight = 36;
const int ItemWidth = 330;
const int TitleHeight = 46;
const int TitleSpace = 2;
const int MaxDeviceCount = 8;

#endif // BLUETOOTHCONSTANTS_H
