/****************************************************************************
** Meta object code from reading C++ file 'notification1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "notification1interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notification1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgDeepinDdeNotification1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgDeepinDdeNotification1Interface",
        "ActionInvoked",
        "",
        "in0",
        "in1",
        "AppAddedSignal",
        "AppInfoChanged",
        "QDBusVariant",
        "in2",
        "AppRemovedSignal",
        "NotificationClosed",
        "RecordAdded",
        "SystemInfoChanged",
        "appAdded",
        "appRemoved",
        "appSettingChanged",
        "systemSettingChanged",
        "ClearRecords",
        "QDBusPendingReply<>",
        "CloseNotification",
        "GetAllRecords",
        "QDBusPendingReply<QString>",
        "GetAppInfo",
        "QDBusPendingReply<QDBusVariant>",
        "GetAppList",
        "QDBusPendingReply<QStringList>",
        "GetCapbilities",
        "GetRecordById",
        "GetRecordsFromId",
        "GetServerInformation",
        "QDBusPendingReply<QString,QString,QString,QString>",
        "QDBusReply<QString>",
        "QString&",
        "out1",
        "out2",
        "out3",
        "GetSystemInfo",
        "Hide",
        "Notify",
        "QDBusPendingReply<uint>",
        "in3",
        "in4",
        "in5",
        "QVariantMap",
        "in6",
        "in7",
        "RemoveRecord",
        "SetAppInfo",
        "SetSystemInfo",
        "Show",
        "Toggle",
        "getAppSetting",
        "recordCount",
        "setAppSetting",
        "allSetting",
        "systemSetting"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActionInvoked'
        QtMocHelpers::SignalData<void(uint, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'AppAddedSignal'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AppInfoChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QDBusVariant &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 4 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'AppRemovedSignal'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NotificationClosed'
        QtMocHelpers::SignalData<void(uint, uint)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'RecordAdded'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'SystemInfoChanged'
        QtMocHelpers::SignalData<void(uint, const QDBusVariant &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { 0x80000000 | 7, 4 },
        }}),
        // Signal 'appAdded'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'appRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'appSettingChanged'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'systemSettingChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ClearRecords'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'CloseNotification'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(19, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'GetAllRecords'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'GetAppInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusVariant>(const QString &, uint)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'GetAppList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'GetCapbilities'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(26, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'GetRecordById'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetRecordsFromId'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(int, const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'GetServerInformation'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,QString,QString,QString>()>(29, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Slot 'GetServerInformation'
        QtMocHelpers::SlotData<QDBusReply<QString>(QString &, QString &, QString &)>(29, 2, QMC::AccessPublic, 0x80000000 | 31, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 32, 34 }, { 0x80000000 | 32, 35 },
        }}),
        // Slot 'GetSystemInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusVariant>(uint)>(36, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'Hide'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(37, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'Notify'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &, uint, const QString &, const QString &, const QString &, const QStringList &, const QVariantMap &, int)>(38, 2, QMC::AccessPublic, 0x80000000 | 39, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 4 }, { QMetaType::QString, 8 }, { QMetaType::QString, 40 },
            { QMetaType::QString, 41 }, { QMetaType::QStringList, 42 }, { 0x80000000 | 43, 44 }, { QMetaType::Int, 45 },
        }}),
        // Slot 'RemoveRecord'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(46, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetAppInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, uint, const QDBusVariant &)>(47, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 4 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'SetSystemInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, const QDBusVariant &)>(48, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::UInt, 3 }, { 0x80000000 | 7, 4 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(49, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'Toggle'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(50, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'getAppSetting'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'recordCount'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>()>(52, 2, QMC::AccessPublic, 0x80000000 | 39),
        // Slot 'setAppSetting'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(53, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'allSetting'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'systemSetting'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgDeepinDdeNotification1Interface, qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgDeepinDdeNotification1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t>.metaTypes,
    nullptr
} };

void OrgDeepinDdeNotification1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgDeepinDdeNotification1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActionInvoked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->AppAddedSignal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->AppInfoChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3]))); break;
        case 3: _t->AppRemovedSignal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->NotificationClosed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 5: _t->RecordAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->SystemInfoChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2]))); break;
        case 7: _t->appAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->appRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->appSettingChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->systemSettingChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QDBusPendingReply<> _r = _t->ClearRecords();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->CloseNotification((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->GetAllRecords();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QDBusVariant> _r = _t->GetAppInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QStringList> _r = _t->GetAppList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QStringList> _r = _t->GetCapbilities();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QString> _r = _t->GetRecordById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QString> _r = _t->GetRecordsFromId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QString,QString,QString,QString> _r = _t->GetServerInformation();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,QString,QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusReply<QString> _r = _t->GetServerInformation((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QDBusVariant> _r = _t->GetSystemInfo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->Hide();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<uint> _r = _t->Notify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->RemoveRecord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->SetAppInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->SetSystemInfo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->Show();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->Toggle();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<QString> _r = _t->getAppSetting((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<uint> _r = _t->recordCount();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->setAppSetting((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(uint , const QString & )>(_a, &OrgDeepinDdeNotification1Interface::ActionInvoked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::AppAddedSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & , uint , const QDBusVariant & )>(_a, &OrgDeepinDdeNotification1Interface::AppInfoChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::AppRemovedSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(uint , uint )>(_a, &OrgDeepinDdeNotification1Interface::NotificationClosed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::RecordAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(uint , const QDBusVariant & )>(_a, &OrgDeepinDdeNotification1Interface::SystemInfoChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::appAdded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::appRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::appSettingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeNotification1Interface::*)(const QString & )>(_a, &OrgDeepinDdeNotification1Interface::systemSettingChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->allSetting(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->systemSetting(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAllSetting(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setSystemSetting(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgDeepinDdeNotification1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgDeepinDdeNotification1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgDeepinDdeNotification1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgDeepinDdeNotification1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void OrgDeepinDdeNotification1Interface::ActionInvoked(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgDeepinDdeNotification1Interface::AppAddedSignal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgDeepinDdeNotification1Interface::AppInfoChanged(const QString & _t1, uint _t2, const QDBusVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void OrgDeepinDdeNotification1Interface::AppRemovedSignal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgDeepinDdeNotification1Interface::NotificationClosed(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void OrgDeepinDdeNotification1Interface::RecordAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgDeepinDdeNotification1Interface::SystemInfoChanged(uint _t1, const QDBusVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void OrgDeepinDdeNotification1Interface::appAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OrgDeepinDdeNotification1Interface::appRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void OrgDeepinDdeNotification1Interface::appSettingChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void OrgDeepinDdeNotification1Interface::systemSettingChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
