/****************************************************************************
** Meta object code from reading C++ file 'ddeindicatortrayprotocol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plugins/application-tray/ddeindicatortrayprotocol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddeindicatortrayprotocol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t {};
} // unnamed namespace

template <> constexpr inline auto tray::DDEindicatorProtocol::qt_create_metaobjectdata<qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tray::DDEindicatorProtocol",
        "registedItemChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'registedItemChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DDEindicatorProtocol, qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject tray::DDEindicatorProtocol::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTrayProtocol::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t>.metaTypes,
    nullptr
} };

void tray::DDEindicatorProtocol::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DDEindicatorProtocol *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->registedItemChanged(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *tray::DDEindicatorProtocol::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tray::DDEindicatorProtocol::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray20DDEindicatorProtocolE_t>.strings))
        return static_cast<void*>(this);
    return AbstractTrayProtocol::qt_metacast(_clname);
}

int tray::DDEindicatorProtocol::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTrayProtocol::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto tray::DDEindicatorProtocolHandler::qt_create_metaobjectdata<qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tray::DDEindicatorProtocolHandler",
        "clicked",
        "",
        "uint8_t",
        "button_index",
        "x",
        "y",
        "textPropertyChanged",
        "QDBusMessage",
        "message",
        "iconPropertyChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(uint8_t, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'textPropertyChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'iconPropertyChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DDEindicatorProtocolHandler, qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject tray::DDEindicatorProtocolHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTrayProtocolHandler::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t>.metaTypes,
    nullptr
} };

void tray::DDEindicatorProtocolHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DDEindicatorProtocolHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast<std::add_pointer_t<uint8_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->textPropertyChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 2: _t->iconPropertyChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DDEindicatorProtocolHandler::*)(uint8_t , int , int )>(_a, &DDEindicatorProtocolHandler::clicked, 0))
            return;
    }
}

const QMetaObject *tray::DDEindicatorProtocolHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tray::DDEindicatorProtocolHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tray27DDEindicatorProtocolHandlerE_t>.strings))
        return static_cast<void*>(this);
    return AbstractTrayProtocolHandler::qt_metacast(_clname);
}

int tray::DDEindicatorProtocolHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTrayProtocolHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void tray::DDEindicatorProtocolHandler::clicked(uint8_t _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
